<?php

$locale["  %d%% (%d/%d)"] =
   "  %d%% (%d/%d)";
$locale[" (to pages linked from \"%s\")"] =
   "(auf Seiten verlinkt von \"%s\")";
$locale[" ... around %s"] =
   "... cirka %s";
$locale[" ... first %d bytes"] =
   " ... erste %d Bytes";
$locale[" ... first %d lines"] =
   " ... erste %d Zeilen";
$locale[" Additionally, try to keep the latest contributions of all authors in the last %d days (even if there are more than %d of them,) but in no case keep more than %d unique author revisions."] =
   "Versuche zustzlich die neuesten Beitrge aller Autoren der letzten %d Tage aufzubewahren (auch wenn es mehr als %d sind), keinesfalls jedoch mehr als %d einzelne Autoren Revisionen.";
$locale[" Keep the latest contributions of the last %d authors up to %d days."] =
   "Aufbewahrung der neueren Beitrge der letzten %d Autoren fr %d Tage.";
$locale[" Keep up to %d minor edits, but keep them no longer than %d days."] =
   "Aufbewahrung kleinerer nderungen fr %d, aber nicht lnger als %d Tage.";
$locale[" Sorry, cannot merge."] =
   " Konnte leider nicht automatisch einpflegen.";
$locale[" replace "] =
   " ersetze mit ";
$locale[" skipped"] =
   " ausgelassen";
$locale["%4d  %s\n"] =
   "%4d  %s\n";
$locale["%d UserPreferences fields successfully updated."] =
   "%d BenutzerEinstellungen erfolgreich auf neuesten Stand gebracht.";
$locale["%d best incoming links: "] =
   "Die %d besten hereinkommenden Links: ";
$locale["%d best outgoing links: "] =
   "Die %d besten hinausgehenden Links: ";
$locale["%d homepages"] =
   "%d Homepages";
$locale["%d minutes"] =
   "%d Minuten";
$locale["%d most popular nearby: "] =
   "Die %d meistbesuchten Seiten in der Nhe: ";
$locale["%d not-empty pages"] =
   "%d nicht leere Seiten";
$locale["%d online users"] =
   "%d Benutzer Online";
$locale["%d page(s) with more than %d hits (>%d%%)."] =
   "%d Seite(n) die mehr als %d aufgerufen haben (>%d%%).";
$locale["%d pages"] =
   "%d Seiten";
$locale["%d pages have been permanently removed."] =
   "%d Seiten wurden unwiderruflich gelscht.";
$locale["%d pages with less than %d hits (<%d%%)."] =
   "%d Seiten die weniger als %d aufgerufen haben (<%d%%).";
$locale["%s %s %s is disallowed on this wiki for %s user '%s' (level: %s)."] =
   "%s %s %s ist auf diesem Wiki fr %s Benutzer %s (Level: %s) nicht zugelassen.";
$locale["%s Kb (%s bytes)"] =
   "%s KB (%s Bytes)";
$locale["%s already exists"] =
   "%s existiert bereits";
$locale["%s at %s"] =
   "%s um %s";
$locale["%s b"] =
   "%s B";
$locale["%s by %s"] =
   "%s von %s";
$locale["%s bytes"] =
   "%s Bytes";
$locale["%s bytes written"] =
   "%s Bytes geschrieben";
$locale["%s days"] =
   "%s Tagen";
$locale["%s does not appear to be a WikiPlugin."] =
   "%s scheint kein Zusatzprogramm zu sein.";
$locale["%s does not exist"] =
   "%s existiert nicht";
$locale["%s does not know about the language '%s', using 'en' instead."] =
   "%s weit nichts von die Sprache %s, stattdessen wird 'en' angewendet.";
$locale["%s has no subpages defined."] =
   "%s hat keine zugewiesenen Unterseiten.";
$locale["%s is disallowed on this wiki."] =
   "%s ist auf diesem Wiki nicht zugelassen.";
$locale["%s is empty"] =
   "%s ist leer";
$locale["%s is empty."] =
   "%s ist leer.";
$locale["%s is listed at %s"] =
   "%s ist auf %s aufgelisted";
$locale["%s is missing"] =
   "%s Argument fehlt";
$locale["%s is not locked!"] =
   "%s ist nicht gesperrt!";
$locale["%s is not writable"] =
   "%s ist nicht nderbar";
$locale["%s is not writable."] =
   "%s is nicht nderbar.";
$locale["%s is only allowed in locked pages."] =
   "%s wird/werden nur in gesperrten Seiten erlaubt.";
$locale["%s k"] =
   "%s k";
$locale["%s not found"] =
   "%s nicht gefunden";
$locale["%s of this page"] =
   "%s von dieser Seite";
$locale["%s on %s:"] =
   "%s um %s:";
$locale["%s or %s parameter missing"] =
   "%s oder %s Argument fehlt";
$locale["%s pages changed."] =
   "%s Seiten gendert.";
$locale["%s pages have been changed."] =
   "%s Seiten wurden gendert.";
$locale["%s pages have been permanently changed."] =
   "%s Seiten wurden gendert.";
$locale["%s pages have been permanently renamed."] =
   "%s Seiten wurden umbenannt.";
$locale["%s pages link to %s:"] =
   "%s Seiten sind mit %s verlinkt:";
$locale["%s pages would link to %s:"] =
   "%s Seiten wrden mit %s verlinkt sein:";
$locale["%s parameter missing"] =
   "%s Argument fehlt";
$locale["%s prediction for you is %.1f stars"] =
   "Die %s Vorraussage fr dich sind %.lf Sterne";
$locale["%s prediction for you is %s stars"] =
   "Die %s Vorraussage fr dich sind %s Sterne";
$locale["%s words"] =
   "%s Wrter";
$locale["%s(%d): no such revision"] =
   "%s(%d): keine solche Version";
$locale["%s: %s"] =
   "%s: %s";
$locale["%s: Bad action"] =
   "%s: Ungltige Aktion";
$locale["%s: Can't open dba database"] =
   "%s: Konnte DBA Datenbank nicht ffnen";
$locale["%s: Date of new revision is %s"] =
   "%s: Datum dieser aktuellen Neubearbeitung ist %s";
$locale["%s: argument index out of range"] =
   "%s: Ungltiger Index in Array";
$locale["%s: error while handling error:"] =
   "%s: Fehler whrend der Fehlerbehandlung von:";
$locale["%s: file not found"] =
   "%s: Datei nicht gefunden";
$locale["%s: no such class"] =
   "Unbekannte Klasse: %s";
$locale["%s: not a subclass of WikiPlugin."] =
   "%s scheint kein WikiPlugin zu sein.";
$locale["%s: not defined"] =
   "%s: nicht definiert";
$locale["&version=-1 might help."] =
   "&version=-1 wird empfohlen.";
$locale["'%s' is no ModeratedPage anymore."] =
   "'%s' ist keine ModeratierteSeite mehr.";
$locale["'%s': Bad page name"] =
   "%s: Ungltiger Seitenname";
$locale["'%s': Bad page name: %s"] =
   "%s: Ungltiger Seitenname: %s";
$locale["'%s': corrupt file"] =
   "%s: Datei korrumpiert";
$locale["'s %d page ratings:"] =
   "s %d Seiten Bewertungen:";
$locale["(Copy your changes to the clipboard. You can try editing a different page or save your text in a text editor.)"] =
   "(Kopieren Sie Ihre Vernderungen in die Zwischenablage. Sie knnen versuchen eine andere Seite zu edieren oder Ihr Text in einem Texteditor speichern.)";
$locale["(Currently not working)"] =
   "(Funktioniert momentan nicht)";
$locale["(Pages which have been deleted at least %s days are already checked.)"] =
   "(Seiten, die in den letzten %s Tagen gelscht wurden, sind bereits ausgewhlt)";
$locale["(Redirected from %s)"] =
   "(Weitergeleitet von %s)";
$locale["(User: %s)"] =
   "(Benutzer: %s)";
$locale["(Your preferences are stored as hidden data within this page)."] =
   "(Ihre Einstellungen sind als versteckte Daten in dieser Seite hintergelegt).";
$locale["(diff)"] =
   "(diff)";
$locale["(disable individual page permissions, enable inheritance)?"] =
   "(deaktiviere individuelle Zugriffsrechte, aktiviere Vererbung)";
$locale["(formatted for PhpWiki developers as pgsrc template, not for backing up)"] =
   "(formatiert fr die PhpWiki Entwickler als pgsrc Vorlage, nicht zum Backup)";
$locale["(formatted for backing up: all revisions)"] =
   "(formatiert zum Backup: Alle Versionen)";
$locale["(hist)"] =
   "(protok.)";
$locale["(max. recursion level: %d)"] =
   "(max. Rekursionstiefe: %d)";
$locale["(normal formatting: latest revision only)"] =
   "(Normales Format: Nur aktuelle Version)";
$locale[", Memory: %s"] =
   ", RAM: %s";
$locale["- saved to database as version %d"] =
   "- in der Datenbank gespeichert als Version %d.";
$locale["- version %d saved to database as version %d"] =
   "- version %d in der Datenbank gespeichert als Version %d.";
$locale["... (first %s words)"] =
   "... (erste %s Wrter)";
$locale["... copied to %s"] =
   "... kopiert nach %s";
$locale["... not copied to %s"] =
   "... nicht kopiert nach %s";
$locale["... not found"] =
   "... nicht gefunden";
$locale["1 day"] =
   "1 Tag";
$locale["1 word"] =
   "1 Wort";
$locale["<%s: no such section>"] =
   "<%s: unbekannte Sektion>";
$locale["<?plugin ModeratedPage ... ?> not found in first line of %s"] =
   "<?plugin ModeratedPage ... ?> nicht in erster Zeile von %s gefunden";
$locale["<empty>"] =
   "<leer>";
$locale["<no matches>"] =
   "<nichts gefunden>";
$locale["<none>"] =
   "<Keine>";
$locale["<not displayed>"] =
   "<nicht angezeigt>";
$locale["<system language>"] =
   "<Sprache des Servers>";
$locale["<system theme>"] =
   "<Darstellung des Systems>";
$locale["<unknown>"] =
   "<unbekannt>";
$locale["A plugin to provide for raw HTML within wiki pages."] =
   "Einer Zusatzprogramm der reine HTML-Befehle im Wiki-Seiten abrufbar stellt.";
$locale["A required argument '%s' is missing."] =
   "Erforderliches Argument %s fehlt.";
$locale["ACCESS DENIED: You must log in to upload files."] =
   "ZUGRIFF VERWEIGERT: Bitte melden Sie sich erst an, um Dateien hochzuladen.";
$locale["ACL"] =
   "ACL";
$locale["ACL changed for page '%s'."] =
   "ACL fr Seite '%s' gendert.";
$locale["ACL not changed for page '%s'."] =
   "ACL fr Seite '%s' nicht gendert.";
$locale["ADDING"] =
   "HINZU";
$locale["ADMIN"] =
   "ADMIN";
$locale["ANON"] =
   "ANON";
$locale["AUTH_GROUP_FILE not defined"] =
   "AUTH_GROUP_FILE nicht definiert";
$locale["About"] =
   "ber";
$locale["Access"] =
   "Zugriff";
$locale["Access denied to change page '%s'."] =
   "Zugang veweigert um Seite '%s' zu ndern.";
$locale["Action page"] =
   "Aktion Seite";
$locale["Add %s hours to the server's local time when reporting times."] =
   "Addieren Sie %s Stunden zur lokalen Serverzeit, bei jeder Zeitanzeige (z.B. Neuestenderungen).";
$locale["Add %s:"] =
   "%s Hinzufgen:";
$locale["Add Comment"] =
   "Neuer Kommentar";
$locale["Add Message"] =
   "Neue Nachricht";
$locale["Add a Comment"] =
   "Kommentar hinzufgen";
$locale["Add this ACL"] =
   "Fge diese ACL hinzu";
$locale["AddCategory"] =
   "NeueKategorie";
$locale["AddComment"] =
   "NeuerKommentar";
$locale["AddCommentPlugin"] =
   "NeuerKommentarPlugin";
$locale["AddPageLink"] =
   "SeitenLink einfgen";
$locale["AddPlugin"] =
   "Plugin einfgen";
$locale["AddingPages"] =
   "SeitenErzeugen";
$locale["Adjust"] =
   "Justieren";
$locale["Admin"] =
   "Admin";
$locale["Admin is also online."] =
   "Administrator ist auch online.";
$locale["Administrators"] =
   "Administratoren";
$locale["All %s are listed below."] =
   "Alle %s sind unten aufgelistet.";
$locale["All pages in this wiki (%d total):"] =
   "Alle Seiten in diesem Wiki (%d insgesamt):";
$locale["All pages with all links in this wiki (%d total):"] =
   "Alle Seiten mit allen Links in diesem Wiki (%d insgesamt):";
$locale["AllPages"] =
   "AlleSeiten";
$locale["AllPagesCreatedByMe"] =
   "AlleSeitenErzeugtVonMir";
$locale["AllPagesLastEditedByMe"] =
   "AlleSeitenEditiertVonMir";
$locale["AllPagesOwnedByMe"] =
   "AlleSeitenImBesitzVonMir";
$locale["AllUsers"] =
   "AlleBenutzer";
$locale["Allow / Deny"] =
   "Erlaube / Sperre";
$locale["Allows selection of multiple pages which get passed to other WikiAdmin plugins."] =
   "Erlaubt die Auswahl mehrerer Seiten, die dann mit weiteren WikiAdmin Zusatzprogrammen bearbeitet werden.";
$locale["Also pages which have been deleted at least %s days."] =
   "Auch Seiten, die in den letzten %s Tagen gelscht wurden.";
$locale["An unnamed PhpWiki"] =
   "Unbenanntes PhpWiki";
$locale["Anonymous Users"] =
   "Anonyme Benutzer";
$locale["Appearance"] =
   "Darstellung";
$locale["Append text to any page in this wiki."] =
   "Fge Text zu einer Seite in diesem Wiki hinzu.";
$locale["AppendText"] =
   "TextHinzufgen";
$locale["AppendText to %s"] =
   "TextHinzufgen zu %s";
$locale["Appending at the end."] =
   "Fge am Ende hinzu.";
$locale["Application name"] =
   "Anwendungsname";
$locale["Application size: %d Kb"] =
   "Anwendungsplatzbedarf: %d KB";
$locale["Approve"] =
   "Akzeptieren";
$locale["Are you sure you want to permanently change access to the selected files?"] =
   "Sind Sie sicher, da Sie die ausgewhlen Seiten wirklich ndern wollen?";
$locale["Are you sure you want to permanently change the markup type of the selected files?"] =
   "Sind Sie sicher, da Sie die ausgewhlen Seiten wirklich ndern wollen?";
$locale["Are you sure you want to permanently change the selected files?"] =
   "Sind Sie sicher, da Sie die ausgewhlen Seiten wirklich ndern wollen?";
$locale["Are you sure you want to permanently chown the selected files?"] =
   "Sind Sie sicher, da Sie die ausgewhlen Seiten wirklich ndern wollen?";
$locale["Are you sure you want to permanently remove the selected files?"] =
   "Sind Sie sicher, da Sie die ausgewhlen Seiten wirklich lschen wollen?";
$locale["Are you sure you want to permanently rename the selected files?"] =
   "Sind Sie sicher, da Sie die ausgewhlen Seiten wirklich umbenennen wollen?";
$locale["Are you sure you want to permanently search & replace text in the selected files?"] =
   "Sind Sie sicher, da Sie alle Wrter in den angegebenen Seiten ersetzen wollen?";
$locale["Argument '%s' not declared by plugin."] =
   "Argument %s nicht im Zusatzprogramm deklariert.";
$locale["Arguments"] =
   "Parameter";
$locale["Attempting to use the directory '%s' instead."] =
   "Versuche stattdessen das Verzeichnis %s zu verwenden.";
$locale["Auth Level"] =
   "Auth. Ebene";
$locale["Auth Method"] =
   "Auth. Methode";
$locale["AuthInfo"] =
   "AuthentifizierungsInfo";
$locale["Authenticated Users"] =
   "Authentifizierte Benutzer";
$locale["Authenticated as %s"] =
   "Authentifiziert als %s";
$locale["Authenticated users on this wiki (%d total):"] =
   "Eingetrage Benutzer in diesem Wiki (Gesamt: %d):";
$locale["Author"] =
   "Autor";
$locale["Author will be logged as %s."] =
   "%s wird als Autor aufgenommen.";
$locale["AuthorHistory"] =
   "AutorenProtokoll";
$locale["AuthorHistoryPlugin"] =
   "AutorenProtokollPlugin";
$locale["Automatically link headers at the top"] =
   "Verlinke berschriften mit Inhaltsverzeichnis";
$locale["Available plugins"] =
   "Verfgbare Einschubprogramme";
$locale["Avg. Rating"] =
   "Durchschnittsbewertung";
$locale["BAD URL -- remove all of <, >, \""] =
   "URL Formfehler - Entfernen Sie alle Zeichen mit <, >, \"";
$locale["BAD phpwiki: URL"] =
   "phpwiki: URL Formfehler";
$locale["BOGO"] =
   "BOGO";
$locale["Back to the previous page."] =
   "Zurck zur vorigen Seite.";
$locale["BackLinks"] =
   "BackLinks";
$locale["BackLinks for %s"] =
   "BackLinks fr %s";
$locale["Backend type: "] =
   "Backend Typ: ";
$locale["Bad Version"] =
   "Ungltige Version";
$locale["Bad file type: %s"] =
   "Ungltiger Dateityp: %s";
$locale["Bad url in src: remove all of <, >, \""] =
   "URL Formfehler in Quellcode: alle der folgenden Zeichen entfernen <, >, \"";
$locale["Blog Archives:"] =
   "Blog Archive:";
$locale["Blog Entries for %s:"] =
   "Blog Eintrge fr %s:";
$locale["Blog page"] =
   "Blog Seite";
$locale["BlogArchives"] =
   "BlogArchiv";
$locale["Blogs"] =
   "Blogs";
$locale["Bogo Users"] =
   "Bogo Benutzer";
$locale["Bold text"] =
   "Fetter Text";
$locale["Browsing pages"] =
   "Das Durchblttern der Seiten dieses Wikis";
$locale["CANCEL"] =
   "ABBRUCH";
$locale["CONVERTING"] =
   "KONVERTIERE";
$locale["CREATED"] =
   "ERZEUGT";
$locale["Cache statistics"] =
   "Cache Statistiken";
$locale["Calendar"] =
   "Kalender";
$locale["CalendarList"] =
   "KalenderListe";
$locale["CalendarListPlugin"] =
   "KalenderListePlugin";
$locale["CalendarPlugin"] =
   "KalenderPlugin";
$locale["Can't inflate data: zlib support not enabled in this PHP"] =
   "Kann Daten nicht dekomprimieren: Die zlib Bibiliothek wurde in PHP nicht installiert/aktiviert.";
$locale["Can't mix '%s' with '%s' type format strings"] =
   "Kann %s Typ-Formatzeichenketten nicht mit %s vermischen.";
$locale["Can't open the upload logfile."] =
   "Die Upload-Logdatei konnte nicht geffnet worden.";
$locale["Can't open zip file '%s' for reading"] =
   "Konnte zip Datei %s nich ffnen zum lesen";
$locale["Cancel"] =
   "Abbrechen";
$locale["Cancel rating"] =
   "Bewertung lschen";
$locale["Cannot create directory '%s'"] =
   "Das Verzeichnis %s kann nicht erzeugt werden";
$locale["Cannot open AUTH_GROUP_FILE %s"] =
   "Kann AUTH_GROUP_FILE %s nicht ffnen";
$locale["Case insensitive?"] =
   "Gross/Kleinschreibung beachten?";
$locale["CategoryCategory"] =
   "KategorieKategorie";
$locale["CategoryGroup"] =
   "KategorieGruppen";
$locale["CategoryHomePages"] =
   "KategorieHomepage";
$locale["CategoryHomepage"] =
   "KategorieHomepage";
$locale["CategoryPage"] =
   "KategorieSeite";
$locale["Change Password"] =
   "ndere Passwort";
$locale["Change Verification Status"] =
   "ndere Besttigungs-Status";
$locale["Change country"] =
   "Land ndern";
$locale["Change markup"] =
   "ndere Formattierung";
$locale["Change markup type"] =
   "ndere Formattierungs-Typ";
$locale["Change page attributes"] =
   "ndern von Eigenschaften";
$locale["Change the markup type of selected pages."] =
   "ndere den Formattierungstyp aller ausgewhlte Seiten.";
$locale["Check any two boxes then %s."] =
   "Whlen Sie zwei Versionen aus, dann %s.";
$locale["Check any two boxes to compare revisions."] =
   "Whlen Sie zwei Versionen zum Vergleich aus.";
$locale["Check to add this ACL"] =
   "Anklicken um diese ACL hinzuzufgen";
$locale["Chmod"] =
   "Chmod";
$locale["Chmod to permission:"] =
   "ndere auf Berechtigung:";
$locale["Chown"] =
   "Chown";
$locale["Chown page '%s' to '%s'."] =
   "Besitzer der Seite '%s' auf '%s' gendert.";
$locale["Chown selected pages"] =
   "Den Besitzer der ausgewhlte Seiten ndern";
$locale["Chown selected pages."] =
   "Den Besitzer ausgewhlte Seiten ndern.";
$locale["Click to authenticate as %s"] =
   "Hier klicken um sich anzumelden als %s";
$locale["Click to de-/select all pages"] =
   "Klicken Sie um alle/keine Seiten auszuwhlen";
$locale["Click to display"] =
   "Klicken um anzuzeigen";
$locale["Click to display all comments"] =
   "Klicken um Kommentare anzuzeigen";
$locale["Click to hide the comments"] =
   "Klicken um Kommentare zu verstecken";
$locale["Click to reverse sort order"] =
   "Klicken Sie um die Reihenfolge umzudrehen";
$locale["Click to sort by %s"] =
   "Sortiere nach %s";
$locale["Close"] =
   "Schlieen";
$locale["Columns: %s."] =
   "Spalten: %s.";
$locale["Comment"] =
   "Kommentar";
$locale["Comment modified on %s by %s"] =
   "Kommentare am %s gendert von %s";
$locale["CommentPlugin"] =
   "KommentarPlugin";
$locale["Comments"] =
   "Kommentare";
$locale["Comments on %s by %s."] =
   "Kommentar zu %s von %s.";
$locale["Complete."] =
   "Fertig.";
$locale["Conflicting Edits!"] =
   "Widersprechende nderungen!";
$locale["Content"] =
   "Inhalt";
$locale["Contents"] =
   "Inhalt";
$locale["ContributedTranslations"] =
   "Meinebersetzungen";
$locale["Control characters not allowed"] =
   "Steuerzeichen nicht erlaubt";
$locale["Convert"] =
   "Konvertieren";
$locale["Convert text into a png image using GD."] =
   "Text mit der GD Bibliothek in ein PNG Bild konvertieren.";
$locale["Converted successfully %d pages"] =
   "%d Seiten erfolgreich konvertiert";
$locale["Converts TeX to an image. May be used to embed formulas in PhpWiki."] =
   "(La)TeX-Dokument nach ein Bild erstellen. Dadurch konnte eine Formel in PhpWiki eingebettet worden.";
$locale["Copyrights"] =
   "Urheberrechte";
$locale["Couldn't change page '%s' to markup type '%s'."] =
   "Konnte die Formattierung der Seite '%s' nicht auf '%s' ndern.";
$locale["Couldn't chmod page '%s' to '%s'."] =
   "Konnte die Berechtigung der Seite '%s' nicht auf '%s' ndern.";
$locale["Couldn't chown page '%s' to '%s'."] =
   "Konnte den Besitzer der Seite '%s' nicht in '%s' ndern.";
$locale["Couldn't connect to %s"] =
   "Kann nicht zu %s verbinden";
$locale["Couldn't rename page '%s' to '%s'."] =
   "Konnte Seite '%s' nicht in '%s' umbenennen.";
$locale["Couldn't start commandline '%s'"] =
   "Konnte Programm %s nicht starten";
$locale["Count"] =
   "Anzahl";
$locale["Create a Wiki page by the provided name."] =
   "Erzeuge neue Wiki Seite mit dem angegebenem Namen.";
$locale["Create a Wiki page."] =
   "Erzeuge eine neue Wiki Seite.";
$locale["Create a new (sub)page"] =
   "Erzeuge eine neue (Unter)Seite";
$locale["Create: %s"] =
   "Erzeugen: %s";
$locale["CreatePage"] =
   "NeueSeite";
$locale["CreateToc"] =
   "InhaltsVerzeichnis";
$locale["CreateTocPlugin"] =
   "InhaltsVerzeichnisPlugin";
$locale["Created by CreatePage"] =
   "Erzeugt von NeueSeite";
$locale["Created directory '%s' for the page dump..."] =
   "Ein Verzeichnis %s wurde erzeugt, um die Dateien abzulegen...";
$locale["Creating pages"] =
   "Das Seitenerzeugung in diesem Wiki";
$locale["Creator"] =
   "Erzeuger";
$locale["Current Language"] =
   "Ausgewhlte Sprache";
$locale["Current Theme"] =
   "Ausgewhlte Darstellung";
$locale["Current language: '%s'"] =
   "Ihre Sprache: %s";
$locale["Current theme: '%s'"] =
   "Ihre Benutzeroberflche: %s";
$locale["Currently not recommended!"] =
   "Momentan nicht empfohlen!";
$locale["DB admin password:"] =
   "DB Admin passwort:";
$locale["DB admin user:"] =
   "DB Admin Benutzername:";
$locale["Database"] =
   "Datenbank";
$locale["Date Format"] =
   "Datumsformat";
$locale["DeadEndPages"] =
   "VerwaisteSeiten";
$locale["DebugGroupInfo"] =
   "DebugGruppenInfo";
$locale["DebugInfo"] =
   "DebugInfo";
$locale["Default InterWiki map file not loaded."] =
   "Standard-Datei der InterWiki-Karte nicht geladen.";
$locale["Default language: '%s'"] =
   "Standardsprache fr dieses Wiki: %s";
$locale["Default preferences will be used."] =
   "Die Vorgabe Benutzereinstellungen werden verwendent.";
$locale["Default theme: '%s'"] =
   "Darstellung des Systems: %s";
$locale["Define a translation for a specified text"] =
   "Definiere die bersetzung fr einen gegebenen Text";
$locale["Define the translation for %s in %s"] =
   "Definiere die bersetzung fr %s nach %s";
$locale["Del/+"] =
   "L/+";
$locale["Delete this ACL"] =
   "Lsche diese ACL";
$locale["Deleted"] =
   "Gelscht";
$locale["Deleted %s pages with invalid names:"] =
   "%s Seiten mit ungltigen Namen gelscht:";
$locale["Deleted %s unreferenced pages:"] =
   "%s unverlinkte Seiten entfernt:";
$locale["Describe %s here."] =
   "Beschreiben Sie %s hier.";
$locale["Description"] =
   "Beschreibung";
$locale["Description: Provides a list of plugins on this wiki."] =
   "Beschreibung: Liste aller Zusatzprogramme in diesem Wiki.";
$locale["Dialog"] =
   "Dialog";
$locale["Didn't removed page '%s'. Access denied."] =
   "Seite %s wurde nicht gelscht. Zugriff verweigert.";
$locale["Diff"] =
   "Diff";
$locale["Diff previous Author"] =
   "Diff zu vorigem Autor";
$locale["Diff previous Revision"] =
   "Diff zu voriger Version";
$locale["Diff: %s"] =
   "Vergleich von: %s";
$locale["Differences between %s and %s of %s."] =
   "Zeilenweiser Vergleich von %3\$s, von %1\$s mit %2\$s.";
$locale["Diffing pages"] =
   "Die Inhalts-Differenz-Seiten dieses Wikis";
$locale["Discussion"] =
   "Diskussion";
$locale["Display arbitrary SQL result tables"] =
   "Zeige Tabelle von SQL Abfragen an";
$locale["Display differences between revisions"] =
   "Zeilenweiser Vergleich der Versionen";
$locale["Displays a list of randomly chosen pages or redirects to a random page."] =
   "Eine liste der zuflliger ausgewhlter Seiten zeigen oder nach einer zuflliger ausgewhlter Seite weiterleiten.";
$locale["Displays a set of photos listed in a text file with optional descriptions"] =
   "Zeigt die Liste der Bilder in einer Textdatei an, mit optionalen Beschreibungen";
$locale["Displays a url in a seperate frame inside our body. Only one frame allowed."] =
   "Zeigt eine URL in einem eigenen (oder gesonderten) Frame innerhalb der Seite. Nur ein Frame ist erlaubt.";
$locale["Don't cache this page."] =
   "Cache diese Seite nicht.";
$locale["Double redirect not allowed."] =
   "Rekursive Redirektion verboten.";
$locale["Download all revisions for backup"] =
   "Alle Versionen fr Backup herunterladen";
$locale["Download for CVS"] =
   "Fr CVS herunterladen.";
$locale["Download for backup"] =
   "Fr Backup herunterladen";
$locale["Download the page contents"] =
   "Runterladen der Seite";
$locale["Downloading html zip dumps"] =
   "Das Herunterladen aller Wiki Seiten als HTML-Dateien in einer Zip Datei";
$locale["Downloading zip dumps"] =
   "Das Herunterladen aller Wiki Seiten als gezippte Datei";
$locale["Dump Pages"] =
   "Seiten Schreiben";
$locale["Dump Pages as XHTML"] =
   "Seiten als XHTML schreiben";
$locale["Dump pages as XHTML"] =
   "Seiten als XHTML Dateien speichern";
$locale["Dump to directory"] =
   "Wiki Seiten als Dateien in lokales Verzeichnis speichern";
$locale["Dumping Pages"] =
   "Die Seiten werden geschrieben";
$locale["Dumping html pages"] =
   "Die Speicherung von Wiki Seiten als HTML-Dateien";
$locale["Dumping serial pages"] =
   "Die Speicherung von Wiki Seiten als Dateien";
$locale["E-Mail"] =
   "E-Mail";
$locale["E-mail"] =
   "E-Mail";
$locale["ERROR uploading '%s': "] =
   "FEHLER beim Hochladen von %s: ";
$locale["Easy navigation buttons for %s"] =
   "Einfache Navgiationsknpfe fr %s";
$locale["Edit"] =
   "Bearbeiten";
$locale["Edit %s"] =
   "Bearbeite %s";
$locale["Edit Area Size"] =
   "Texteingabe Fenstergre";
$locale["Edit Old Revision"] =
   "Alte Version Bearbeiten";
$locale["Edit aborted."] =
   "Bearbeiten abgebrochen.";
$locale["Edit metadata for %s"] =
   "Meta-Daten fr %s bearbeiten";
$locale["Edit old revision"] =
   "Alte Version Bearbeiten";
$locale["Edit this page"] =
   "Diese Seite bearbeiten";
$locale["Edit this page and all subpages"] =
   "Bearbeiten aller Seiten und Unterseiten";
$locale["Edit: %s"] =
   "Bearbeite: %s";
$locale["EditMetaData"] =
   "MetaDatenBearbeiten";
$locale["EditMetaDataPlugin"] =
   "MetaDatenBearbeitenPlugin";
$locale["EditText"] =
   "TextBearbeiten";
$locale["Edited by: %s"] =
   "Bearbeitet von: %s";
$locale["Editing pages"] =
   "ndern in diesem Wiki";
$locale["Elapsed time: %s s"] =
   "Dauer: %s s";
$locale["Email Verification"] =
   "E-Mail Besttigung";
$locale["Email not yet verified."] =
   "E-Mail noch nicht besttigt.";
$locale["Email verified."] =
   "E-Mail besttigt.";
$locale["Embed hidden comments in WikiPages."] =
   "Kommentar in WikiText verstecken.";
$locale["Embedded image"] =
   "Bild einfgen";
$locale["Empty Preferences or format of UserPreferences cookie not recognised."] =
   "Leere BenutzerEinstellungen oder BenutzerEinstellungs Cookie nicht erkannt.";
$locale["Empty link to: %s"] =
   "Leerer Link zu: %s";
$locale["Empty pagename!"] =
   "Leerer Seitenname!";
$locale["Enable configurable polls"] =
   "Erlaubt konfigurierbare Umfragen";
$locale["Enter pages seperated by space or comma. Wildcards (fileglobbing) allowed."] =
   "Liste aller Seiten durch Leerzeichen oder Komma getrennt. Regulre Ausdrcke (fileglobbing) erlaubt.";
$locale["Enter your UserId to sign in"] =
   "Tragen Sie bitte fr die Anmeldung im Wiki Ihren Benutzernamen ein";
$locale["Error: Empty search string."] =
   "Fehler: Leeres Suchwort.";
$locale["Error: The user HomePage must be a valid WikiWord. Sorry, UserPreferences cannot be saved."] =
   "Fehler: Ihre Homepage Seite mu ein gltiges WikiWord sein. Die BenutzerEinstellungen knnen deshalb leider nicht gespeichert werden.";
$locale["Every"] =
   "Jeder";
$locale["Example.jpg"] =
   "Beispiel.jpg";
$locale["Existing page-level metadata for %s:"] =
   "Zugewiesene Seiten Meta-Daten fr %s:";
$locale["External Links"] =
   "Externe Links";
$locale["External link (remember http:// prefix)"] =
   "Externer Link (http:// prefix)";
$locale["ExternalSearch"] =
   "FremdSuche";
$locale["ExternalSearchPlugin"] =
   "FremdSuchePlugin";
$locale["FAILED"] =
   "FEHLER";
$locale["FIXED"] =
   "AUSGEBESSERT";
$locale["FORBIDDEN"] =
   "VERBOTEN";
$locale["Failed to set LDAP protocol version to 3"] =
   "Fehler beim Setzen der LDAP Protokoll Version 3";
$locale["Fatal PhpWiki Error"] =
   "Fataler PhpWiki Fehler";
$locale["File names may only contain alphanumeric characters and dot, underscore or dash."] =
   "Dateinamen drfen nur folgende Zeichen enthalten: alphanumerische Zeichen, Punkt, Unterstrich und Bindestrich.";
$locale["File successfully uploaded."] =
   "Datei erfolgreich hochgeladen.";
$locale["FileInfo"] =
   "DateiInfo";
$locale["Files with extension %s are not allowed."] =
   "Dateien mit der Endung %s sind nicht erlaubt.";
$locale["FindPage"] =
   "SeiteFinden";
$locale["First"] =
   "Erste";
$locale["FoafViewer"] =
   "FoafBetrachter";
$locale["FoafViewerPlugin"] =
   "FoafViewerPlugin";
$locale["FrameInclude"] =
   "FrameEinbetten";
$locale["FrameIncludePlugin"] =
   "FrameEinbettenPlugin";
$locale["From english to %s: "] =
   "Von Englisch nach %s: ";
$locale["Full Search"] =
   "VolltextSuche";
$locale["Full text search results for '%s'"] =
   "Volltext-Suchresultate nach %s";
$locale["FullDump"] =
   "VollSicherung";
$locale["FullRecentChanges"] =
   "AlleNeuestenderungen";
$locale["FullTextSearch"] =
   "VolltextSuche";
$locale["FuzzyPages"] =
   "FuzzySuche";
$locale["General Auth Settings"] =
   "Allgemeine Authentifizierungs-Einstellungen";
$locale["Get an email notification at changes of the following pages:"] =
   "E-Mail Nachricht bei nderung folgender Seiten:";
$locale["Get debugging information for %s."] =
   "Debug-Informationen von %s.";
$locale["Get preferences information for current user %s."] =
   "Zeige Benutzereinstellungen fr den aktuellen Benutzer %s.";
$locale["Given password ignored."] =
   "Passwort ignoriert.";
$locale["Go"] =
   "Los";
$locale["Go to %s."] =
   "Gehe zu %s.";
$locale["Go to or create page."] =
   "Gehe zu oder erzeuge diese Seite.";
$locale["Go?"] =
   "Los?";
$locale["GoTo"] =
   "GeheZu";
$locale["GoodStyle"] =
   "GuterStil";
$locale["GooglePlugin"] =
   "GoogleZusatzprogramm";
$locale["Grant"] =
   "Erlaube";
$locale["Group %s does not exist"] =
   "Gruppe %s existiert nicht";
$locale["Group page '%s' does not exist"] =
   "Gruppenseite %s existiert nicht";
$locale["Group/User"] =
   "Gruppe/Benutzer";
$locale["Guest"] =
   "Gast";
$locale["Guests"] =
   "Gste";
$locale["H"] =
   "H.";
$locale["HasHomePage"] =
   "HaHomePage";
$locale["Headline text"] =
   "berschrift";
$locale["Height"] =
   "Hhe";
$locale["HelloWorld"] =
   "HalloWelt";
$locale["HelloWorldPlugin"] =
   "HalloWeltPlugin";
$locale["Here you can override site-specific default values."] =
   "Hier knnen Sie einige Voreinstellungen ndern.";
$locale["Hide %s:"] =
   "%s verstecken:";
$locale["Hide or show LinkIcons (if supported by the current theme). Useful for text-only browsers or slow connections."] =
   "LinkIcons ausblenden oder einblenden (unter Voraussetzung da es mit dem ausgewhlter Darstellung untersttzt wurde). Werde wertvoll sein fr die die mit Text-only browsers anschauen oder langsamer Konnexionen.";
$locale["Hilight referred search terms."] =
   "Hebe externe Suchwrter hervor.";
$locale["History of all major and minor edits by %s to page %s."] =
   "Verlaufsprotokoll aller groen und kleinen nderungen von %s der Seite %s.";
$locale["History of all major and minor modifications for any page edited by %s."] =
   "Verlaufsprotokoll aller groen und kleinen nderungen aller Seiten, die von %s bearbeitet wurden.";
$locale["History of all major edits by %s to page %s."] =
   "Verlaufsprotokoll aller groen nderungen von %s der Seite %s.";
$locale["History of changes."] =
   "nderungsprotokoll.";
$locale["History of major modifications for any page edited by %s."] =
   "Verlaufsprotokoll aller groen nderungen aller Seiten, die von %s bearbeitet wurden.";
$locale["Hit statistics"] =
   "Treffer Statistiken";
$locale["Hits"] =
   "Treffer";
$locale["Hits:"] =
   "Treffer:";
$locale["Home"] =
   "Start";
$locale["HomePage"] =
   "StartSeite";
$locale["HomePageAlias"] =
   "HomePageAlias";
$locale["Horizontal line"] =
   "Horizontale Trennlinie";
$locale["HowToUseWiki"] =
   "WieManWikiBenutzt";
$locale["I'm just doing minor edits. Please divert the usual logging to %s instead."] =
   "Ich mache nur kleinere nderungen. Protokolliere stattdessen in %s.";
$locale["I'm sorry, there is no such page as %s."] =
   "Leider gibt es keine solche Seite %s.";
$locale["I'm sorry.  Version %d of %s is not in the database."] =
   "Leider ist keine Version %d von %s in der Datenbank.";
$locale["Ignore wiki formatting"] =
   "Keine Wiki Formatierung";
$locale["Illegal chars %s removed"] =
   "Ungltiges Zeichen %s entfernt";
$locale["Image loaded from cache file: %s"] =
   "Bild geladen von Cachedatei: %s";
$locale["Image saved to cache file: %s"] =
   "Bild gespeichert als Cachedatei: %s";
$locale["In the time since you started editing this page, another user has saved a new version of it."] =
   "Whrend der Zeit, seit Sie mit der Bearbeitung dieser Seite begonnen haben, hat ein anderer Benutzer bereits eine neuere Version gespeichert.";
$locale["In total there are %d user sessions online. :: Unique %d Registered and %d Guests"] =
   "Insgesamt sind %d Benutzersessions online. :: %d verschiedene Registrierte und %d Gste";
$locale["Include an external web page within the body of a wiki page."] =
   "Einbetten einer externen Webseite im Body dieser Wiki Seite.";
$locale["Include multiple pages."] =
   "Fge mehrere Seiten ein.";
$locale["Include of '%s' failed."] =
   "Das Einfgen von %s ist fehlgeschlagen.";
$locale["Include recursively all linked pages starting at %s"] =
   "Bette rekursiv alle verlinkten Seiten ein, angefangen mit %s";
$locale["Include text from another wiki page."] =
   "Text von einer andere Seite einfgen.";
$locale["IncludePage"] =
   "SeiteEinfgen";
$locale["IncludePagePlugin"] =
   "SeiteEinfgenPlugin";
$locale["IncludePages"] =
   "SeitenEinfgen";
$locale["IncludeSiteMap"] =
   "SeitenBaumEingefgt";
$locale["Included from %s"] =
   "Eingefgter Text von %s";
$locale["Included from %s:"] =
   "Eingefgter Text von %s:";
$locale["Includes the content of all SubPages of the current page."] =
   "Enthlt den Inhalt alle UnterSeiten der aktuellen Seite.";
$locale["Info"] =
   "Info";
$locale["Inline images"] =
   "Eingebundene Bilder";
$locale["Insert"] =
   "Einfgen";
$locale["Insert Categories (double-click)"] =
   "Kategorien einfgen (Doppelklick)";
$locale["Insert PageLink (double-click)"] =
   "SeitenLink einfgen (Doppelklick)";
$locale["Insert Plugin (double-click)"] =
   "Plugin einfgen (Doppelklick)";
$locale["Insert Template (double-click)"] =
   "Vorlage einfgen (Doppelklick)";
$locale["Insert non-formatted text here"] =
   "Fge unformatierten Text hier ein";
$locale["Insufficient permissions."] =
   "Keine ausreichenden Zugangsrechte.";
$locale["InterWiki"] =
   "InterWiki";
$locale["InterWiki Address"] =
   "InterWiki-Adresse";
$locale["InterWikiMap"] =
   "InterWikiKarte";
$locale["InterWikiSearch"] =
   "InterWikiSuche";
$locale["Invalid ACL"] =
   "Ungltige ACL";
$locale["Invalid [] syntax ignored"] =
   "Ungltige [] syntax ignoriert";
$locale["Invalid argument: %s=%s"] =
   "Ungltiger Parameter: %s=%s";
$locale["Invalid chmod string"] =
   "Ungltiger CHMOD Befehl";
$locale["Invalid color: %s"] =
   "Ungltige Farbe: %s";
$locale["Invalid image size"] =
   "Ungltige Bildgre";
$locale["Invalid password or userid."] =
   "Ungltiges Passwort oder falscher Benutzername.";
$locale["Invalid password."] =
   "Ungltiges Passwort.";
$locale["Invalid username '%s' for LDAP Auth"] =
   "Ungltiger Benutzername %s fr LDAP Auth";
$locale["Invalid username."] =
   "Ungltiger Benutzername.";
$locale["Italic text"] =
   "Kursiver Text";
$locale["JabberPresence"] =
   "JabberAnwesend";
$locale["Keep up to %d major edits, but keep them no longer than %d days."] =
   "Aufbewahrung grerer nderungen fr %d, aber nicht lnger als %d Tage.";
$locale["LDAP_AUTH_HOST not defined"] =
   "LDAP_AUTH_HOST nicht definiert";
$locale["Language"] =
   "Sprache";
$locale["Last"] =
   "Letzte";
$locale["Last Author"] =
   "Letzter Autor";
$locale["Last Modified"] =
   "Zuletzt gendert";
$locale["Last Summary"] =
   "Letzte Zusammenfassung";
$locale["Last edited %s"] =
   "Zuletzt gendert %s";
$locale["Last edited on %s"] =
   "Zuletzt bearbeitet am %s";
$locale["LatestSnapshot"] =
   "LetzeSicherung";
$locale["Layout tables using a very rich markup style."] =
   "Tabellen mit erweiterter HTML Syntax.";
$locale["Layout tables using the old markup style."] =
   "Tabellen unter Verwendung traditioneller (alter) Wikitext Formatierung.";
$locale["LdapSearch"] =
   "LdapSuche";
$locale["Leading %s not allowed"] =
   "Fhrende %s nicht erlaubt";
$locale["Legend"] =
   "Legende";
$locale["Level 1 headline"] =
   "H1 berschrift";
$locale["Like Pages"] =
   "hnliche Seiten";
$locale["LikePages"] =
   "hnlicheSeiten";
$locale["Line %s does not begin with a '|'."] =
   "Zeile %s beginnt nicht mit '|'.";
$locale["Link to page"] =
   "Link auf Seite";
$locale["LinkDatabase"] =
   "LinkDatenbank";
$locale["LinkIcons"] =
   "LinksIcons";
$locale["Links"] =
   "Links";
$locale["List PageHistory for %s"] =
   "Das nderungsprotokoll fr %s auflisten";
$locale["List all once authenticated users."] =
   "Liste alle eingetragen Benutzer.";
$locale["List all page revisions edited by one user with diff links, or show a PageHistory-like list of a single page for only one user."] =
   "Liste aller Versionen eines Autors mit Diff-Links, oder eine SeitenProtokoll-hnliche Liste einer Seite nur fr einen Autor.";
$locale["List all pages in this wiki."] =
   "Alle Seiten in diesem Wiki auflisten.";
$locale["List all pages which link to %s."] =
   "Alle Seiten, die mit %s verlinkt sind.";
$locale["List all pages."] =
   "Alle Seiten auflisten.";
$locale["List of pages created by [%s] (%d total):"] =
   "Liste der Seiten erzeugt von [%s] (%d insgesamt):";
$locale["List of pages last edited by [%s] (%d total):"] =
   "Liste der Seiten last edited by [%s] (%d insgesamt):";
$locale["List of pages owned by [%s] (%d total):"] =
   "Liste der Seiten owned by [%s] (%d insgesamt):";
$locale["List page names which share an initial or final title word with '%s'."] =
   "Diese Seiten teilen sich einen Wordteil am Anfang oder Ende mit %s.";
$locale["List pages which are not linked to by any other page."] =
   "Liste aller Seiten, die von keiner anderen Seite verlinkt sind.";
$locale["List the most popular pages nearby."] =
   "Liste die meistbesuchten Seiten in der Nhe.";
$locale["List the most popular pages."] =
   "Die meistbesucht Seiten werden aufgelistet.";
$locale["List the user's ratings."] =
   "Zeige die Benutzer Bewertungen.";
$locale["List this page and all subpages"] =
   "Auflistung aller Seiten und Unterseiten";
$locale["ListPages"] =
   "ListeSeiten";
$locale["ListSubpages"] =
   "UnterseitenListe";
$locale["Lists referenced page names which do not exist yet."] =
   "Zeige verlinkte Seiten, die noch nicht bearbeitet bzw. erzeugt wurden.";
$locale["Lists the names of all SubPages of the current page."] =
   "Listet die Namen aller Unterseiten der aktuellen Seite.";
$locale["LiveSearch"] =
   "LiveSuche";
$locale["Load File"] =
   "Datei Laden";
$locale["LoadDump"] =
   "SeiteLaden";
$locale["Loading '%s'"] =
   "%s wird geladen";
$locale["Loading InterWikiMap from external file %s."] =
   "Die InterWikikarte wird von der externen Datei %s geladen.";
$locale["Loading files"] =
   "Das Dateienladen in diesem Wiki";
$locale["Loading up virgin wiki"] =
   "Lade neue Seiten in das frische Wiki";
$locale["Lock"] =
   "Sperren";
$locale["Lock Page"] =
   "Seite Sperren";
$locale["Lock page to enable link"] =
   "Seite sperren, um den Link zu aktivieren";
$locale["Locked"] =
   "Gesperrt";
$locale["Locking pages"] =
   "Das Seitensperrung in diesem Wiki";
$locale["Login"] =
   "Anmelden";
$locale["MIME file %s"] =
   "MIME-Datei %s";
$locale["MISSING"] =
   "FEHLEND";
$locale["Make use of the Google API"] =
   "Benutze die Google API";
$locale["Markup"] =
   "Quelltext";
$locale["Markup cache purged!"] =
   "HTML-Cachedaten entfernt!";
$locale["Markup:"] =
   "Quelltextformat:";
$locale["Members:"] =
   "Mitglieder:";
$locale["Merge Edit"] =
   "Zusammenfgen Bearbeiten";
$locale["Merge and Edit: %s"] =
   "Zusammenfgen und Bearbeiten: %s";
$locale["Message"] =
   "Nachricht";
$locale["Method '%s' not implemented in this GROUP_METHOD %s"] =
   "Methode %s in GROUP_METHOD %s nicht implementiert";
$locale["Minor"] =
   "kleinere";
$locale["Minor Edit"] =
   "Kleinere nderung";
$locale["Miscellaneous utility functions for the Administrator."] =
   "Verschiedene Dienstfunktionen fr den Administrator.";
$locale["Missing %s for %s"] =
   "Fehlender %s fr %s";
$locale["Missing PagePermission:"] =
   "Fehlende Zugriffsberechtigung:";
$locale["ModeratedPage"] =
   "ModerierteSeite";
$locale["ModeratedPage Notification Error: Couldn't send email"] =
   "ModerierteSeite Benachrichtigungsfehler: Konnte kein E-Mail versenden";
$locale["ModeratedPage: No emails for the moderators defined"] =
   "ModerierteSeite: Keine E-Mails fr Moderatoren definiert";
$locale["Modern"] =
   "Modern";
$locale["Modified"] =
   "Gendert";
$locale["Moniker"] =
   "Kurzname";
$locale["Most users ever online was %d at %s."] =
   "Die meisten Besucher online waren %d am %s.";
$locale["MostPopular"] =
   "MeistBesucht";
$locale["Name"] =
   "Seitenname";
$locale["Never edited"] =
   "Noch nie bearbeitet.";
$locale["New Topic"] =
   "Neues Thema";
$locale["New comment."] =
   "Neuer Kommentar.";
$locale["New page"] =
   "Neue Seite";
$locale["New password"] =
   "Neues Passwort";
$locale["New users may use an empty password."] =
   "Neue Benutzer knnen auch ohne Passwort einloggen.";
$locale["Newer page:"] =
   "Neuere Seite:";
$locale["Next"] =
   "Nchste";
$locale["Next Month"] =
   "Nchster Monat";
$locale["No Blog Entries"] =
   "Keine Blog Eintrge";
$locale["No LDAP in this PHP version"] =
   "Kein LDAP in dieser PHP Version";
$locale["No changes found"] =
   "Keine nderungen gefunden.";
$locale["No changes."] =
   "Keine nderungen.";
$locale["No comments found"] =
   "Keine Kommentare gefunden.";
$locale["No empty, unreferenced pages were found."] =
   "Keine leeren, unverlinkten Seiten gefunden.";
$locale["No or not enough GROUP_DB SQL statements defined"] =
   "Keine oder zu wenige GROUP_DB SQL Statements definiert";
$locale["No or unsupported GROUP_METHOD defined"] =
   "Keine oder ungltige GROUP_METHOD definiert";
$locale["No other page links to %s yet."] =
   "Noch keine Seiten sind mit %s verlinkt.";
$locale["No page links to %s."] =
   "Keine Seiten sind mit %s verlinkt.";
$locale["No pagedata for %s"] =
   "Keine Daten fr Seite %s";
$locale["No pagename specified"] =
   "Keine Seite angegeben";
$locale["No pages changed."] =
   "Keine nderungen.";
$locale["No pages renamed."] =
   "Keine Seiten umbenannt.";
$locale["No pages with bad names had to be deleted."] =
   "Keine Seiten mit ungltigen Namen muten gelscht werden.";
$locale["No revisions found"] =
   "Keine Versionen gefunden";
$locale["No uploaded file to upload?"] =
   "Keine Datei zum Hochladen?";
$locale["NoCache"] =
   "OhneCache";
$locale["None"] =
   "Keine";
$locale["Not enough questions answered!"] =
   "Nicht gengend Fragen beantwortet!";
$locale["Note that many browsers will automatically adjust the width of the editing area so that it fills the browser window.  In this case, the width preference will be ignored."] =
   "Beachten Sie bitte, dass viele Browser die Breite der Textbox automatisch an ihre Fensterbreite anpassen. In diesem Fall wird die hier eingegebene Breite ignoriert.";
$locale["Note, that user accounts with bouncing emails will be disabled."] =
   "Beachten Sie bitte, da Benutzer mit ungltigen E-Mail Addressen gelscht werden.";
$locale["Note:"] =
   "Hinweis:";
$locale["Note: Only if you create your personal HomePage with same the pagename as your user id, you will be able to store your UserPreferences. Otherwise not."] =
   "Beachte: Nur wenn Sie Ihre persnliche HomePage mit dem selben Seitennamen wie Ihre Benutzernamen erzeugen, werden Sie Ihre BenutzerEinstellungen speichern knnen.";
$locale["Nothing found"] =
   "Nichts gefunden";
$locale["OK"] =
   "OK";
$locale["Ok"] =
   "Ok";
$locale["Okay"] =
   "OK";
$locale["Old UserPage %s without stored password updated with empty password. Set a password in your UserPreferences."] =
   "Ihre alte persnliche HomePage %s ohne gespeichertem Passwort wurde mit einem leeren Password gespeichert. Setzen Sie ein Passwort in Ihren BenutzerEinstellungen.";
$locale["OldStyleTable"] =
   "TraditionellerTabellenStil";
$locale["OldStyleTablePlugin"] =
   "TraditionellerTabellenStilPlugin";
$locale["OldTextFormattingRules"] =
   "AlteTextFormatierungsRegeln";
$locale["Older page:"] =
   "ltere Seite:";
$locale["One page links to %s:"] =
   "Eine Seite ist mit %s verlinkt:";
$locale["One page would link to %s:"] =
   "Eine Seite wrde mit %s verlinkt sein:";
$locale["Only files with extension HTML are allowed"] =
   "Nur Dateien mit der Endung HTML sind erlaubt";
$locale["Oops! Revision %s of %s seems to have been deleted!"] =
   "Hoppla! Es scheint, die Version %s von %s wurde gelscht!";
$locale["Optimizing database"] =
   "Datenbank wird optimiert";
$locale["Original (1.2 or 1.0)"] =
   "Original (1,2 oder 1,0)";
$locale["Orphaned Pages in this wiki (%d total):"] =
   "Verwaiste Seiten in diesem Wiki (%d gesamt):";
$locale["OrphanedPages"] =
   "VerwaisteSeiten";
$locale["Other diffs:"] =
   "Andere Vergleiche:";
$locale["Other version"] =
   "Andere Version";
$locale["Our users created a total of %d pages."] =
   "Unsere Benutezr erzeugten insgesamt %d Seiten.";
$locale["Owner"] =
   "Besitzer";
$locale["Owner: %s"] =
   "Besitzer: %s";
$locale["PHP syntax highlighting"] =
   "Hervorhebung der PHP-Syntax (Syntax highlighting)";
$locale["PHP was unable to create a new GD image stream. Read 'lib/plugin/text2png.php' for details."] =
   "PHP konnte keinen neues GD Bild erzeugen. Lesen Sie 'lib/plugin/text2png.php' fr Details.";
$locale["Page %s already exists. Ignored."] =
   "Seite %s existiert bereits. Ignoriert.";
$locale["Page %s not found."] =
   "Seite %s nicht gefunden.";
$locale["Page Content: "] =
   "Inhalt: ";
$locale["Page Execution took %s seconds"] =
   "Ausfhrung dieser Seite dauerte %s Sekunden";
$locale["Page Locked"] =
   "Seite Gesperrt";
$locale["Page Name"] =
   "Seitenname";
$locale["Page Trail"] =
   "Spur";
$locale["Page Type:"] =
   "Seitentyp:";
$locale["Page Version:"] =
   "Seiten Version:";
$locale["Page change"] =
   "Seiten nderung";
$locale["Page could not be updated. %s doesn't exist!\n"] =
   "Seite konnte nicht gendert werden. %s existiert nicht!\n";
$locale["Page names with prefix '%s'"] =
   "Seitenamen mit dem Anfangswort %s";
$locale["Page names with suffix '%s'"] =
   "Seitennamen mit Endwort %s";
$locale["Page now locked."] =
   "Seite jetzt gesperrt.";
$locale["Page now unlocked."] =
   "Seite jetzt freigegeben.";
$locale["Page removed %s"] =
   "Seite gelscht %s";
$locale["Page rename %s to %s"] =
   "Seite %s nach umbenennen %s";
$locale["Page statistics"] =
   "Seiten Statistiken";
$locale["Page successfully updated."] =
   "Datei erfolgreich gendert.";
$locale["PageChange Notification Error: Couldn't send %s to %s"] =
   "Seitennderung Benachrichtigung Fehler: Konnte %s nicht an %s senden";
$locale["PageChange Notification of %s sent to %s"] =
   "Seitennderung Benachrichtigung von %s an %s gesendet";
$locale["PageDump"] =
   "SeiteSpeichern";
$locale["PageGroup"] =
   "SeitenGruppe";
$locale["PageGroup for %s"] =
   "SeitenGruppe fr %s";
$locale["PageGroupTest"] =
   "SeitenGruppeTest";
$locale["PageGroupTest/Four"] =
   "SeitenGruppenTest/Vier";
$locale["PageGroupTest/One"] =
   "SeitenGruppenTest/Eins";
$locale["PageGroupTest/Three"] =
   "SeitenGruppenTest/Drei";
$locale["PageGroupTest/Two"] =
   "SeitenGruppenTest/Zwei";
$locale["PageHistory"] =
   "SeitenProtokoll";
$locale["PageHistory for %s"] =
   "Verlaufsprotokoll fr Seite %s";
$locale["PageInfo"] =
   "SeitenInfo";
$locale["PageTrail Plugin"] =
   "PageTrail Plugin";
$locale["Pagedata size: %d Kb"] =
   "Gre der Seitendaten: %d KB";
$locale["Password cannot be changed."] =
   "Passwort konnte nicht gendert werden.";
$locale["Password updated."] =
   "Passwort gendert.";
$locale["Password was not changed."] =
   "Passwort wurde nicht gendert.";
$locale["Password:"] =
   "Passwort:";
$locale["Perform searches on InterWiki sites listed in InterWikiMap."] =
   "Durchsuchen im InterWiki sites die im InterWikiMap verzeichnet sind.";
$locale["Permanently remove all selected pages."] =
   "Endgltige Lschung aller ausgewhlten Seiten.";
$locale["Permanently remove the selected files:"] =
   "Lsche alle ausgewhlten Seiten endgltig:";
$locale["Permission"] =
   "Zugriffsrecht";
$locale["Personal Auth Settings for '%s'"] =
   "Spezielle Authentifizierungs-Einstellungen %s";
$locale["Personal language:"] =
   "Ihre Sprache:";
$locale["Personal theme:"] =
   "Ihre Benutzeroberflche:";
$locale["PersonalPage login method:"] =
   "PersonalPage Login Methode:";
$locale["PgsrcTranslation"] =
   "PgsrcTranslation";
$locale["PhotoAlbum"] =
   "BilderAlbum";
$locale["PhotoAlbumPlugin"] =
   "BilderAlbumPlugin";
$locale["Photos"] =
   "Album";
$locale["PhpHighlight"] =
   "PhpHighlight";
$locale["PhpHighlightPlugin"] =
   "PhpHighlightPlugin";
$locale["PhpWeather"] =
   "PhpWetter";
$locale["PhpWeatherPlugin"] =
   "PhpWetterPlugin";
$locale["PhpWiki"] =
   "PhpWiki";
$locale["PhpWiki engine version"] =
   "PhpWikitriebwerksversion";
$locale["PhpWikiAdministration"] =
   "PhpWikiSystemverwalten";
$locale["PhpWikiAdministration/Chmod"] =
   "PhpWikiSystemverwalten/Chmod";
$locale["PhpWikiAdministration/Chown"] =
   "PhpWikiSystemverwalten/Chown";
$locale["PhpWikiAdministration/Markup"] =
   "PhpWikiSystemverwalten/Formattierung";
$locale["PhpWikiAdministration/Remove"] =
   "PhpWikiSystemverwalten/Lschen";
$locale["PhpWikiAdministration/Rename"] =
   "PhpWikiSystemverwalten/Umbenennen";
$locale["PhpWikiAdministration/Replace"] =
   "PhpWikiSystemverwalten/SuchenErsetzen";
$locale["PhpWikiAdministration/SetAcl"] =
   "PhpWikiSystemverwalten/AclSetzen";
$locale["PhpWikiDocumentation"] =
   "PhpWikiDokumentation";
$locale["PhpWikiPoll"] =
   "PhpWikiUmfrage";
$locale["Please check it through before saving."] =
   "Bitte berprfen Sie erst alles, bevor Sie es abspeichern.";
$locale["Please contact your PhpWiki administrator for assistance."] =
   "Bitte bitten Sie Ihren PhpWiki Administrator um Untersttzung.";
$locale["Please ensure that %s is writable, or redefine %s in config/config.ini."] =
   "Bitte berprfen Sie, da %s nderbar ist, oder ndern Sie %s in config/config.ini.";
$locale["Please set ENCRYPTED_PASSWD to false in config/config.ini and probably change ADMIN_PASSWD."] =
   "Sie haben vergessen ENCRYPTED_PASSWD auf true zu setzen. Bitte aktualisieren Sie config/config.ini und berprfen sie auch ADMIN_PASSWD.";
$locale["Please set ENCRYPTED_PASSWD to true in config/config.ini."] =
   "Sie haben vergessen ENCRYPTED_PASSWD auf true in config/config.ini zu setzen.";
$locale["Please set a password in UserPreferences."] =
   "Bitte setzen Sie ein Passwort in Ihren BenutzerEinstellungen.";
$locale["Please use one of the downloadable versions rather than copying and pasting from the above preview."] =
   "Verwenden Sie bitte eine der herunterladbaren Versionen als von der obigen Vorschau zu Kopieren und Einzufgen.";
$locale["Ploticus"] =
   "Ploticus";
$locale["PloticusPlugin"] =
   "PloticusPlugin";
$locale["Plugin"] =
   "Zusatzprogramm";
$locale["Plugin %s disabled."] =
   "Zusatzprogramm %s deaktiviert.";
$locale["Plugin %s failed."] =
   "Zusatzprogramm %s fehlgeschlagen.";
$locale["Plugin %s: undefined"] =
   "Zusatzprogramm %s: undefiniert";
$locale["PluginManager"] =
   "ZusatzprogrammManager";
$locale["Plugins"] =
   "Zusatzprogramme";
$locale["PopularNearby"] =
   "MeistBesuchtNahe";
$locale["Post new"] =
   "Neuer Eintrag";
$locale["Posted: %s"] =
   "Gepostet: %s";
$locale["Preferences"] =
   "Voreinstellungen";
$locale["PreferencesInfo"] =
   "EinstellungenInfo";
$locale["PrevNext"] =
   "VorigeNchste";
$locale["Preview"] =
   "Vorschau";
$locale["Preview as backup format"] =
   "Vorschau als Backupformat";
$locale["Preview as developer format"] =
   "Vorschau im Entwickler Format";
$locale["Preview as normal format"] =
   "Vorschau als normales Format";
$locale["Preview only!  Changes not saved."] =
   "Dies ist nur eine Vorschau! Die nderungen sind noch nicht gespeichert.";
$locale["Preview: Page dump of %s"] =
   "Vorschau: Seitendump von %s";
$locale["Previous"] =
   "Vorherige";
$locale["Previous Author"] =
   "Voriger Autor";
$locale["Previous Major Revision"] =
   "Vorige grssere Neubearbeitung";
$locale["Previous Month"] =
   "Voriger Monat";
$locale["Previous Revision"] =
   "Vorige Neubearbeitung";
$locale["Printer"] =
   "Drucker";
$locale["Propagate new permissions to all subpages?"] =
   "Aktiviere Vererbung dieser Zugriffsrechte auf alle Unterseiten?";
$locale["Purge HTML cache for this page. Regenerate from WikiMarkup when next accessed."] =
   "Gespeicherten HTML Cache dieser Seite lschen und beim nchsten Aufruf neu generieren.";
$locale["Purge Markup Cache"] =
   "HTML-Cachedatei Subern";
$locale["Purge all Pages With Invalid Names"] =
   "Alle Seiten mit ungltigen Namen endgltig entfernen";
$locale["Purge all empty, unreferenced Pages"] =
   "Alle leeren Seiten endgltig entfernen, die nicht verlinkt sind.";
$locale["PurgeHtmlCache"] =
   "HtmlCacheSubern";
$locale["Querying backend directly for '%s'"] =
   "DB Debug Informationen von der Seite %s";
$locale["Quick Search"] =
   "SchnellSuche";
$locale["RandomPage"] =
   "ZufallsSeite";
$locale["Rate"] =
   "Bewerte";
$locale["Rate It"] =
   "Bewerte es";
$locale["Rate the topic of this page"] =
   "Bewerte den Seitentitel";
$locale["RateIt"] =
   "BewerteEs";
$locale["Rated by %d users | Average rating %.1f stars"] =
   "Bewertet von %d Benutzern | Durchschnittswertung: %.1f Sterne";
$locale["Rating system. Store user ratings per page"] =
   "Bewertungssystem. Speichere Benutzerbewertungen pro Seite";
$locale["Raw HTML"] =
   "Reine HTML-Befehle";
$locale["Raw HTML is disabled in this wiki."] =
   "HTML-Befehle sind in diesem Wiki ausser Kraft gesetzt.";
$locale["RawHtmlPlugin"] =
   "RawHtmlPlugin";
$locale["Recent Comments"] =
   "Neueste Kommentare";
$locale["Recent Edits"] =
   "Geringfgige nderungen";
$locale["RecentChanges"] =
   "Neuestenderungen";
$locale["RecentComments"] =
   "NeuesteKommentare";
$locale["RecentEdits"] =
   "Geringfgigenderungen";
$locale["RecentVisitors"] =
   "LetzteBesucher";
$locale["Recursive redirect to self: '%s'"] =
   "Eigenbezogene Selbstrckleitung: %s";
$locale["Recursively get BackLinks or links"] =
   "Alle BackLinks fr %s (rekursiv)";
$locale["Redirect"] =
   "Weiterleiten";
$locale["Redirect to an external url"] =
   "Weiterleitung zu einer externen Webseite";
$locale["RedirectTo"] =
   "WeiterLeiten";
$locale["RedirectToPlugin"] =
   "WeiterLeitenPlugin";
$locale["Redirects to an external web site based on form input"] =
   "Weiterleitung der Suche zu einer externen Webseite aufgrund einer Formulareingabe";
$locale["Redirects to another url or page."] =
   "Weiterleitung zu einer externen Webseite oder localer Seite.";
$locale["References"] =
   "Funoten";
$locale["Regex?"] =
   "Regulrer Ausdruck?";
$locale["Registered Users"] =
   "Angemeldete Benutzer";
$locale["Registered Users Online: "] =
   "Registrierte Benutzer Online: ";
$locale["Reject"] =
   "Ablehnen";
$locale["Related Changes"] =
   "Verlinkte nderungen";
$locale["Related Links"] =
   "Verwandte Links";
$locale["RelatedChanges"] =
   "Verlinktenderungen";
$locale["Remove"] =
   "Lschen";
$locale["Remove Page"] =
   "Seite Lschen";
$locale["Remove Preferences"] =
   "Lsche Voreinstellungen";
$locale["Remove selected pages"] =
   "Ausgewhlte Seiten lschen";
$locale["Remove this page"] =
   "Lschen der Seite";
$locale["Removed by: %s"] =
   "Gelscht von: %s";
$locale["Removed page '%s' successfully."] =
   "Seite %s erfolgreich gelscht.";
$locale["Removing pages"] =
   "Die Seitenlschung in diesem Wiki";
$locale["Rename"] =
   "Umbenennen";
$locale["Rename selected pages"] =
   "Ausgewhlte Seiten umbenennen";
$locale["Rename to"] =
   "Umbennen zu";
$locale["Renamed page '%s' to '%s'."] =
   "Seite '%s' auf '%s' umbenannt.";
$locale["Replace all occurences of the given string in the content of all pages."] =
   "Ersetze alle Wrter in den angegebenen Seiten.";
$locale["Replace with"] =
   "Ersetze mit";
$locale["Replace: "] =
   "Ersetze: ";
$locale["Replaced '%s' with '%s' in page '%s'."] =
   "'%s' mit '%s' in Seite '%s' ersetzt.";
$locale["Reply"] =
   "Antwort";
$locale["Requires WikiAdmin privileges to edit."] =
   "Verlangt Administratorenrechte zur Bearbeitung.";
$locale["Reset"] =
   "Zurcksetzen";
$locale["Restore Anyway"] =
   "Ungeprft berschreiben";
$locale["Return to %s"] =
   "Zurck zu %s";
$locale["Revert"] =
   "Zurckspeichern";
$locale["Reverting to a previous version of pages"] =
   "Zurckspeichern einer lteren Version";
$locale["Revision Not Found"] =
   "Version nicht gefunden";
$locale["RichTable"] =
   "ErweiterteTabellen";
$locale["RichTablePlugin"] =
   "ErweiterteTabellenPlugin";
$locale["SOAP access"] =
   "SOAP Zugriff";
$locale["SandBox"] =
   "SandKasten";
$locale["Save"] =
   "Speichern";
$locale["Saved on:"] =
   "Gespeichert am:";
$locale["Saved: %s"] =
   "Gespeichert: %s";
$locale["Saving this page will overwrite the current version."] =
   "Wenn Sie diese Seite jetzt speichern, wird die aktuelle Version berschrieben.";
$locale["Score"] =
   "Gewichtung";
$locale["Search"] =
   "Suche";
$locale["Search & Replace"] =
   "Suchen & Ersetzen";
$locale["Search an LDAP directory"] =
   "Durchsuche ein LDAP Verzeichnis";
$locale["Search and replace text in selected wiki pages."] =
   "Suche und ersetze Text in den gewhlten Seiten.";
$locale["Search for page titles similar to %s."] =
   "Suche nach Seitentitel die hnlich klingen wie %s.";
$locale["Search string '%s' not found in content of page '%s'."] =
   "Das Suchwort '%s' wurde nicht in der Seite '%s' gefunden.";
$locale["Search the content of all pages in this wiki."] =
   "Den Text aller Seiten dieses Wikis durchsuchen.";
$locale["Search the titles of all pages in this wiki."] =
   "Die Titeln aller Seiten dieses Wikis durchsuchen.";
$locale["SearchHighlight"] =
   "SucheHervorheben";
$locale["See %s"] =
   "Siehe %s";
$locale["See %s tips for editing."] =
   "Siehe %s Tips frs Edieren.";
$locale["See: %s"] =
   "Siehe: %s";
$locale["Select"] =
   "Auswahl";
$locale["Select pages"] =
   "Seiten auswhlen";
$locale["Select the pages to change the markup type:"] =
   "Whlen Sie die Seiten zum ndern:";
$locale["Select the pages to change the owner:"] =
   "Whlen Sie die Seiten zum ndern:";
$locale["Select the pages to change:"] =
   "Whlen Sie die Seiten zum ndern:";
$locale["Select the pages to rename:"] =
   "Whle Seiten zum Umbenennen aus:";
$locale["Select the pages to search:"] =
   "Seiten auswhlen:";
$locale["Select: "] =
   "Auswahl: ";
$locale["Selected Grant checkboxes allow access, unselected checkboxes deny access."] =
   "Gesetzte Erlaube Kstchen erlauben Zugriff, ungesetzte Kstchen sperren Zugriff.";
$locale["Selected Pages: "] =
   "Ausgewhlte Seiten: ";
$locale["Selected page '%s' passed to '%s'."] =
   "Ausgewhlte Seite %s an %s bergeben.";
$locale["Serialized file %s"] =
   "Serialisierte Datei %s";
$locale["Set Password"] =
   "Setze Passwort";
$locale["Set USE_DB_SESSION to false."] =
   "Setzen Sie USE_DB_SESSION auf false.";
$locale["Set individual page permissions."] =
   "Setze individuelle Zugangsrechte.";
$locale["SetAcl"] =
   "AclSetzen";
$locale["Show all changes for:"] =
   "Zeige alle nderungen innerhalb von:";
$locale["Show and add blogs for %s"] =
   "Blogs fr %s zeigen und hinzufgen";
$locale["Show and add comments for %s"] =
   "Kommentare fr %s zeigen und hinzufgen";
$locale["Show changes for:"] =
   "Zeige nderungen innerhalb von:";
$locale["Show extra page Info and statistics for %s."] =
   "Zustzliche Seiten-Info und Statistiken ber %s zeigen.";
$locale["Show minor edits for:"] =
   "Zeige kleinere nderungen innerhalb von:";
$locale["Show relative dates using 'Today' and 'Yesterday'"] =
   "Datum mit relativen Bezeichnungen, wie Heute und Gestern";
$locale["Show summary information from the access log table."] =
   "Zeige berblick ber die Access LOG Tabelle.";
$locale["Show summary information of the current user sessions."] =
   "Zeige berblick ber alle aktuellen Benutzersessions.";
$locale["Show translations of various words or pages"] =
   "Zeige bersetzungen fr verschiedene Wrter oder Seiten";
$locale["Sidebar"] =
   "Sidebar";
$locale["Sign In"] =
   "Anmelden";
$locale["Sign Out"] =
   "Abmelden";
$locale["Sign in as:"] =
   "Anmelden als:";
$locale["Sign in:"] =
   "Anmelden:";
$locale["SignIn"] =
   "AnMelden";
$locale["SignOut"] =
   "Abmelden";
$locale["Signed Users"] =
   "Angemeldete Benutzer";
$locale["Signed as %s"] =
   "Angemeldet as %s";
$locale["Simple RSS Feed aggregator Plugin"] =
   "Einfaches RSS Feed Plugin";
$locale["Simple Sample Plugin"] =
   "Zusatzprogramm Minimalbeispiel";
$locale["Simple jabber presence plugin"] =
   "Einfaches Jabber-Anwesenheits Zusatzprogramm";
$locale["Since you started the deletion process, someone has saved a new version of %s.  Please check to make sure you still want to permanently remove the page from the database."] =
   "Whrend Sie den Lschungsprozess begonnen haben, hat jemand anderer eine neue Version von %s gespeichert. Bitte entscheiden Sie ob Sie die Seite noch von der Datenbank permanent lschen wollen.";
$locale["SiteMap"] =
   "Seitenbersicht";
$locale["Size"] =
   "Gre";
$locale["Size:"] =
   "Gre:";
$locale["Skipped."] =
   "Ausgelassen.";
$locale["Skipping"] =
   "bersprungen";
$locale["Some of the changes could not automatically be combined.  Please look for sections beginning with '%s', and ending with '%s'.  You will need to edit those sections by hand before you click Save."] =
   "Einige der nderungen konnten nicht automatisch miteinander verbunden werden. Bitte suchen Sie nach den Teilen, die mit %s anfangen und mit %s enden. Sie mssen diese Teile von Hand bearbeiten, bevor Sie auf Speichern klicken.";
$locale["Someone has edited the page!"] =
   "Jemand hat die Seite bereits bearbeitet!";
$locale["Sorry but this file is too big."] =
   "Leider ist diese Datei zu gro.";
$locale["Sorry for the inconvenience."] =
   "Entschuldigen Sie bitte die hiermit fr Sie verbundenen Unannehmlichkeiten.";
$locale["Sorry! You must wait at least 20 minutes until you can vote again!"] =
   "Leider! Du kannst erst wieder in 20 Minuten whlen!";
$locale["Sorry, no dynamic DB Session support."] =
   "Leider! Dynamische DB Session Untersttzung nicht vorhanden.";
$locale["Sorry, this page is not in the database."] =
   "Leider, Seite %s ist nicht in der Datenbank.";
$locale["Sorry, this version of PHP cannot create PNG image files."] =
   "Das geht leider nicht. Diese PHP Version kann keine PNG Bilder erzeugen.";
$locale["Sort by %s"] =
   "Sortiere nach %s";
$locale["Sound Score"] =
   "Aussprachliche";
$locale["Spam Prevention"] =
   "AntiSpam";
$locale["SpamAssassin reports: "] =
   "SpamAssassin sagt: ";
$locale["Spelling Score"] =
   "Buchstabierende";
$locale["SqlResult"] =
   "SqlErgebnis";
$locale["Statistics about %s."] =
   "Statistik ber %s.";
$locale["Status:"] =
   "Gltigkeit:";
$locale["String \"%s\" not found."] =
   "Zeichenkette \"%s\" nicht gefunden.";
$locale["SubPages of %s:"] =
   "Unterseiten von %s:";
$locale["Submit"] =
   "Eingeben";
$locale["Submit country"] =
   "Land eingeben";
$locale["Submit location"] =
   "Land eingeben";
$locale["Subpage"] =
   "Unterseite";
$locale["Summary"] =
   "Zusammenfassung";
$locale["Supplanted on:"] =
   "Ersetzt am:";
$locale["Support moderated pages"] =
   "Untersttze moderierte Seiten";
$locale["Supported handlers are: %s"] =
   "Untersttzte DBA Methoden sind: %s";
$locale["Supported languages"] =
   "Untersttzte Sprachen";
$locale["Supported themes"] =
   "Unterstzte Benutzeroberflche";
$locale["Switch to detailed list"] =
   "Wechsle zu detallierter Liste";
$locale["Switch to summary"] =
   "Zur bersicht wechseln";
$locale["Synopsis"] =
   "bersicht";
$locale["Syntax language not specified."] =
   "Keine Syntax angegeben.";
$locale["SyntaxHighlighter"] =
   "SyntaxHervorhebung";
$locale["Table Of Contents"] =
   "Inhaltsverzeichnis";
$locale["TeX directory not writable."] =
   "Keine Schreibrechte fr das TeX Verzeichnis.";
$locale["Template"] =
   "Vorlage";
$locale["TermsOfUse"] =
   "BenutzungsBedingungen";
$locale["TextFormattingRules"] =
   "TextFormatierungsRegeln";
$locale["Thank you for editing %s."] =
   "Danke fr das Bearbeiten von %s.";
$locale["Thanks for adding this translation!"] =
   "Danke fr diese bersetzung!";
$locale["Thanks for participating!"] =
   "Danke fr die Teilnahme!";
$locale["The %d least popular pages of this wiki:"] =
   "Die %d selten besuchten Seiten dieses Wikis:";
$locale["The %d most popular pages of this wiki:"] =
   "Die %d meistbesuchten Seiten dieses Wikis:";
$locale["The %d most recent %s are listed below."] =
   "Die %d jngste %s sind unten aufgelistet.";
$locale["The %d most recent %s during the past %s days are listed below."] =
   "Die %d jngste %s innerhalb der letzten %s Tage sind unten aufgelistet.";
$locale["The %d most recent %s during the past day are listed below."] =
   "Die %d jngste %s innerhalb des letzten Tages sind unten aufgelistet.";
$locale["The %d oldest %s are listed below."] =
   "Die %d lteste %s sind unten aufgelistet.";
$locale["The %d oldest %s during the past %s days are listed below."] =
   "Die %d lteste %s innerhalb der letzten %s Tage sind unten aufgelistet.";
$locale["The %d oldest %s during the past day are listed below."] =
   "Die %d lteste %s innerhalb des letzten Tages sind unten aufgelistet.";
$locale["The %s files are in the %s directory. Please read the INSTALL file and move the database to a permanent location or risk losing all the pages!"] =
   "Die %s Dateien liegen im Verzeichnis %s. Bitte lesen Sie jetzt zuerst die INSTALL Anleitung und verschieben Sie danach die DB Datei an einen anderen endgltigen Speicherplatz, Sie laufen sonst Gefahr, alle Seiten zu verlieren.";
$locale["The %s subpage enables simple weblogging."] =
   "Die %s UnterSeite ermglicht ein einfaches Weblog.";
$locale["The DBA handler %s is unsupported!"] =
   "Die DBA Methode %s wird nicht untersttzt!";
$locale["The ICAO '%s' wasn't recognized."] =
   "Die angegebene ICAO %s war nicht bekannt.";
$locale["The PhpWeather plugin provides weather reports from the Internet."] =
   "Der PhpWetter plugin gibt Auskunft zur Wetterlage vom Internet.";
$locale["The PhpWiki access log file"] =
   "Die PhpWiki Zugriffslog Datei";
$locale["The PhpWiki programming team"] =
   "Das PhpWiki Programmierer-Team";
$locale["The SQL_ACCESS_LOG is not enabled."] =
   "SQL_ACCESS_LOG ist nicht aktiviert.";
$locale["The current page has no subpages defined."] =
   "Diese Seite hat keine zugewiesenen Unterseiten.";
$locale["The current time at the server is %s."] =
   "Die Uhrzeit am Server ist gerade %s.";
$locale["The length of the password is shorter than the system policy allows."] =
   "Die Lnge des Passwortes ist krzer als vom System gefordert.";
$locale["The length of the stored password is shorter than the system policy allows. Sorry, you cannot login.\n You have to ask the System Administrator to reset your password."] =
   "Die Lnge des gespeicherten Passwortes ist krzer als vom System gefordert.Sie knnen sich leider nicht anmelden.\n Sie mssen den System Administrator bitten, Ihr Passwort neu zu setzen.";
$locale["The most recent %s during the past %s days are listed below."] =
   "Die jngste %s innerhalb der letzten %s Tage sind unten aufgelistet.";
$locale["The most recent %s during the past day are listed below."] =
   "Die jngste %s innerhalb des letzten Tages sind unten aufgelistet.";
$locale["The newest registered user is %s."] =
   "Wir haben insgesamt %d registrierte Benutzer.";
$locale["The requested information is available only to Administrators."] =
   "Diese Information ist nur fr Administratoren zugnglich.";
$locale["The result of this poll so far:"] =
   "Aktuelle Ergebnisse der Umfrage:";
$locale["The session.save_path directory"] =
   "Das session.save_path Verzeichnis";
$locale["The upload logfile is not writable."] =
   "Die Upload Logdatei ist nicht schreibbar.";
$locale["Theme"] =
   "Benutzeroberflche";
$locale["There is already a file with name %s uploaded."] =
   "Es existiert schon eine gleichnamige, hochgeladene Datei %s.";
$locale["There is no image creation data available to id '%s'. Please reload referring page."] =
   "Es sind keine Bilddaten vorhanden fr '%'. Bitte laden Sie die Seite neu.";
$locale["These page titles match fuzzy with '%s'"] =
   "Diese Seitentitel sind das Ergebnis der FuzzySuche nach %s.";
$locale["These pages share an initial or final title word with '%s'"] =
   "Diese Seiten teilen sich einen Wordteil am Anfang oder Ende mit %s";
$locale["This data is based on users active over the past %s."] =
   "Diese Daten basieren auf den Benutzern fr die letzten %s.";
$locale["This is a minor change."] =
   "Kleinere nderung.";
$locale["This page already exists"] =
   "Diese Seite existiert bereits";
$locale["This page edit seems to contain spam and was therefore not saved."] =
   "Diese Bearbeitung scheint Spam beinzuhalten und wurde ignoriert.";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Diese Seite wurde vom Systemadministrator gesperrt und kann nicht bearbeitet werden.";
$locale["This page has been locked by the administrator so your changes can not be saved."] =
   "Diese Seite wurde vom Administrator fr die allgemeine Bearbeitung gesperrt. Ihre nderungen knnen deshalb nicht gespeichert werden.";
$locale["Time Zone"] =
   "Zeitzone";
$locale["Title"] =
   "Titel";
$locale["Title Search"] =
   "TitelSuche";
$locale["Title search results for '%s'"] =
   "Titel-Suchresultate nach %s";
$locale["Title:"] =
   "Titel:";
$locale["TitleSearch"] =
   "TitelSuche";
$locale["To add check 'Add' near the dropdown list."] =
   "Setze '+' um ACL Zeile hinzufgen.";
$locale["To ignore delete the line."] =
   "Lsche Zeile mit 'X' um ACL Eintrag zu ignorieren.";
$locale["Today"] =
   "Heute";
$locale["Too many external links."] =
   "Zu viele externe Links.";
$locale["Top & bottom toolbars"] =
   "Obere u. untere Werkzeugleisten";
$locale["Top Recommendations"] =
   "Beste Bewertungungen";
$locale["Total %d plugins: "] =
   "%d Gesammte Zusatzprogramme: ";
$locale["Total of %d languages: "] =
   "%d Sprache gesammt: ";
$locale["Total of %d themes: "] =
   "%d Benutzeroberflche gesamt: ";
$locale["Transclude"] =
   "Einbetten";
$locale["TranscludePlugin"] =
   "EinbettenPlugin";
$locale["Transcluded from %s"] =
   "Eingebetteter Text von %s";
$locale["Transcluded page"] =
   "Eingebettete Seite";
$locale["Translate"] =
   "bersetzen";
$locale["Translate %s to %s in %s"] =
   "bersetze '%s' nach '%s' in %s";
$locale["Translate '%s' to '%s' in *%s*"] =
   "bersetze '%s' nach '%s' in *%s*";
$locale["TranslateText"] =
   "bersetzeText";
$locale["Translation Error!"] =
   "bersetzungsfehler!";
$locale["Type"] =
   "Typ";
$locale["Type it again"] =
   "Bitte hier wiederholen";
$locale["UNOBTAINABLE"] =
   "UNERREICHBAR";
$locale["USER"] =
   "BENUTZER";
$locale["Unable to bind LDAP server %s using %s %s"] =
   "Konnte nicht LDAP Server %s verbinden. mit %s %s";
$locale["Unable to connect to IMAP server "] =
   "IMAP Server nicht gefunden ";
$locale["Unable to connect to LDAP server %s"] =
   "Konnte LDAP Server %s nicht finden";
$locale["Unable to find src='%s'"] =
   "Konnte src='%s' nicht lesen";
$locale["Unable to load: %s"] =
   "Konnte %s nicht laden";
$locale["Unable to open directory '%s' for reading"] =
   "Konnte Verzeichnis %s nicht zum Lesen ffnen";
$locale["Unable to read src='%s'"] =
   "Konnte src='%s' nicht lesen";
$locale["Undefined method %s for special group %s"] =
   "Undefinierte Methode %s fr Spezialgruppe %s";
$locale["Undo"] =
   "Rckgngig";
$locale["Undo Search & Replace"] =
   "Suchen & Ersetzen rckgngig machen";
$locale["Undo disabled"] =
   "Undo deaktiviert";
$locale["Unexpected EOF in zip file"] =
   "Unerwartetes Dateiende (EOF-Fehler) in ZIP Datei";
$locale["UnfoldSubpages"] =
   "UnterseitenEntfalten";
$locale["UnfoldSubpagesPlugin"] =
   "UnterseitenEntfaltenPlugin";
$locale["Unknown special group '%s'"] =
   "Unbekannte Spezialgruppe %s";
$locale["Unlock"] =
   "Entsperren";
$locale["Unlock Page"] =
   "Seite Freigeben";
$locale["Unlocking pages"] =
   "Die Seitenfreigabe in diesem Wiki";
$locale["Unrecognised parameter 'mode=%s'"] =
   "Ungltiges Argument 'mode=%s'";
$locale["Unsupported ACL access type %s ignored."] =
   "Nicht untersttzter ACL Zugiffsmodus %s ignoriert.";
$locale["Unsupported argument: %s=%s"] =
   "Nicht untersttztes Argument: %s=%s";
$locale["Unsupported format argument %s"] =
   "Nicht untersttzter format Parameter %s";
$locale["Up"] =
   "Oben";
$locale["UpLoad"] =
   "HochLaden";
$locale["UpLoadPlugin"] =
   "HochLadenPlugin";
$locale["Update Preferences"] =
   "Einstellungen Speichern";
$locale["Upgrade"] =
   "Updaten";
$locale["Upload"] =
   "Hochladen";
$locale["Upload File"] =
   "Datei Hochladen";
$locale["Uploading %s"] =
   "%s wird hochgeladen";
$locale["Uploading failed."] =
   "Hochladen fehlgeschlagen.";
$locale["Uploading zip dumps"] =
   "Das Hochladen vonr ZIP-Speicherauszge in diesem Wiki";
$locale["Use old markup"] =
   "Alte Formatierungssyntax verwenden";
$locale["User page"] =
   "Benutzer Seite";
$locale["User preferences for user '%s':"] =
   "Einstellungen fr Benutzer '%s':";
$locale["User statistics"] =
   "Benutzer Statistiken";
$locale["User: %s"] =
   "Benutzer: %s";
$locale["UserId"] =
   "Benutzername";
$locale["UserId:"] =
   "Benutzername:";
$locale["UserPreferences"] =
   "BenutzerEinstellungen";
$locale["UserRatings"] =
   "BenutzerBewertungen";
$locale["Users will not be able to sign in."] =
   "Benutzer werden sich nicht anmelden knnen.";
$locale["Using directory '%s'"] =
   "Das Verzeichnis %s wird verwendet";
$locale["Verification Status"] =
   "Besttigungs-Status";
$locale["Verify the current action"] =
   "Besttigen Sie die gegenwrtige Aktion";
$locale["Version"] =
   "Version";
$locale["Version %d"] =
   "Version %d.";
$locale["Version %s"] =
   "Version %s.";
$locale["Version %s, saved %s"] =
   "Version %s. %s gespeichert";
$locale["Version %s, saved on %s"] =
   "Version %s. gespeichert am %s";
$locale["Versions are identical"] =
   "Versionen sind identisch";
$locale["View Source"] =
   "QuellTextAnsicht";
$locale["View Source: %s"] =
   "Quelltext Ansicht: %s";
$locale["View a single page dump online."] =
   "Betrachte das interne Speicherformat einer einzelnen Seite.";
$locale["View the current version"] =
   "Die aktuelle Version ansehen";
$locale["View this page and all subpages"] =
   "Anzeige aller Seiten und Unterseiten";
$locale["Viewing redirecting page."] =
   "Zeige Redirekt-Seite.";
$locale["Viewing the source of pages"] =
   "DieQuelltextansicht der Seiten in diesem Wiki";
$locale["Visited pages on this wiki, ordered by popularity:"] =
   "Die besuchten Seiten dieses Wikis, nach Popularitt geordnet:";
$locale["W"] =
   "Br.";
$locale["WARNING: InterWikiMap page is unlocked, so not using those links."] =
   "ACHTUNG: Die InterWikiKarte Seite ist ungesperrt. Ignoriert.";
$locale["Wanted From"] =
   "Bentigt von";
$locale["Wanted Pages for %s (%d total):"] =
   "WunschZettelSeiten fr %s (%d gesamt):";
$locale["Wanted Pages for %s:"] =
   "WunschZettelSeiten fr %s:";
$locale["Wanted Pages in this wiki (%d total):"] =
   "WunschZettelSeiten in diesem Wiki (%d gesamt):";
$locale["Wanted Pages in this wiki:"] =
   "WunschZettelSeiten in diesem Wiki:";
$locale["WantedPages"] =
   "WunschZettelSeiten";
$locale["Warning!"] =
   "Achtung!";
$locale["Warning:"] =
   "Achtung:";
$locale["Warning: The search string cannot be empty!"] =
   "Achtung! Das Suchwort darf nicht leer sein!";
$locale["Warning: You are editing an old revision."] =
   "Achtung: Sie bearbeiten eine alte Version.";
$locale["We have a total of %d registered users."] =
   "Wir haben insgesamt %d registrierte Benutzer.";
$locale["Welcome to %s!\nYour email account is verified and\nwill be used to send page change notifications.\nSee %s"] =
   "Willkommen bei %s!\nIhr E-Mail Konto ist besttigt und\nwird benutzt, um Seitennderungs Benachrichtigungen per E-Mail zu versenden.\nSiehe %s";
$locale["What links here"] =
   "Was verlinkt hierher";
$locale["Who Is Online"] =
   "Wer ist Online";
$locale["Who is online"] =
   "Wer ist Online";
$locale["WhoIsOnline"] =
   "WerIstOnline";
$locale["Width"] =
   "Breite";
$locale["Wiki Name"] =
   "Name des Wikis";
$locale["WikiAdminChmod"] =
   "WikiAdminChmod";
$locale["WikiAdminChown"] =
   "WikiAdminChown";
$locale["WikiAdminMarkup"] =
   "WikiAdminFormattierung";
$locale["WikiAdminMarkup from %s to %s"] =
   "WikiAdminFormattierung von %s auf %s";
$locale["WikiAdminRemove"] =
   "WikiAdminLschen";
$locale["WikiAdminRename"] =
   "WikiAdminUmbenennen";
$locale["WikiAdminSearchReplace"] =
   "WikiAdminSuchenErsetzen";
$locale["WikiAdminSearchReplace %s by %s"] =
   "WikiAdminSuchenErsetzen %s mit %s";
$locale["WikiAdminSelect"] =
   "WikiAdminAuswahl";
$locale["WikiAdminSetAcl"] =
   "WikiAdminAclSetzen";
$locale["WikiAdminUtils"] =
   "WikiAdminUtils";
$locale["WikiAdminUtils says:"] =
   "WikiAdminUtils sagt:";
$locale["WikiBlog"] =
   "WikiBlog";
$locale["WikiBlogPlugin"] =
   "WikiBlogPlugin";
$locale["WikiDB::renamePage() not yet implemented for this backend"] =
   "WikiDB::renamePage() fr dieses Backend noch nicht implementiert";
$locale["WikiForm"] =
   "WikiFormular";
$locale["WikiForm: %s: unknown action"] =
   "WikiForm: %s: unbekannte Aktion";
$locale["WikiForum"] =
   "WikiForum";
$locale["WikiPlugin"] =
   "WikiPlugin";
$locale["WikiPoll"] =
   "WikiUmfrage";
$locale["WikiWikiWeb"] =
   "WikiWikiWeb";
$locale["Wikiname regexp"] =
   "Wikiname regexp";
$locale["With the current offset, this would be reported as %s."] =
   "Mit dem eingegebenen Zeit-Unterschied, wrde die Zeit %s angezeigt.";
$locale["World"] =
   "Welt";
$locale["Wrong password. Try again."] =
   "Falsches Password. Noch einmal eingeben.";
$locale["XML-RPC access"] =
   "XML-RPC Zugriff";
$locale["Yes"] =
   "Ja";
$locale["You are about to remove '%s'!"] =
   "Sie sind im Begriff %s zu lschen!";
$locale["You are signed but not authenticated as %s. "] =
   "Angemeldet aber nicht authentifiziert als %s.";
$locale["You are signed in as %s"] =
   "Sie sind angemeldet als %s";
$locale["You are viewing an old revision of this page."] =
   "Sie sehen eine alte Version dieser Seite.";
$locale["You can personalize various settings in %s."] =
   "Sie knnen knnen einige Eintellungen in %s individuell gestalten.";
$locale["You forgot to set ENCRYPTED_PASSWD to true. Please update your config/config.ini"] =
   "Sie haben vergessen ENCRYPTED_PASSWD auf true zu stellen. Bitte aktualisieren Sie config/config.ini";
$locale["You have not made any changes so no new version has been saved."] =
   "Sie haben keine nderungen vorgenommen, deshalb konnte keine neue Version gespeichert werden.";
$locale["You may sign in using any [WikiWord|AddingPages] as a user id. (Any characters in %s etc. may be used too). The user id will be used as a link in RecentChanges to your home page."] =
   "Sie knnen sich mit jedem gewnschten [WikiWort|SeitenErzeugen] als Benutzernamen ins Wiki eintragen. (Auch %s u. deutsche Umlaute sind zulssig). Der Benutzername wird in Neuestenderungen als Link auf Ihre Homepage verwendet. Sie knnen Ihre Seite in die Browser Favoriten eintragen oder auch gleich als URL verwenden: ~http://www.wikiname.de/~IhrName";
$locale["You must be an administrator to %s."] =
   "Sie mssen Administratorrechte haben %s.";
$locale["You must be an administrator to use this plugin."] =
   "Sie mssen Administratorrechte haben, um dieses Zusatzprogramm zu benutzen.";
$locale["You must be logged in to view ratings."] =
   "Sie mssen sich anmelden um die Bewertungen zu sehen.";
$locale["You must log in to %s."] =
   "Sie mssen sich anmelden %s.";
$locale["You must sign in to %s."] =
   "Sie mssen sich anmelden %s.";
$locale["You must specify a directory to dump to"] =
   "Sie mssen zum Sichern ein Verzeichnis angeben.";
$locale["You must wait for moderator approval."] =
   "Sie mssen auf Moderator approval warten.";
$locale["You searched for: "] =
   "Sie suchten nach: ";
$locale["You stored an empty password in your '%s' page."] =
   "Sie haben ein leeres Passwort in Ihrer HomePage %s gespeichert.";
$locale["Your E-Mail:"] =
   "Ihre E-Mail-Adresse:";
$locale["Your UserPreferences have been successfully deleted."] =
   "Ihre BenutzerEinstellungen wurden erfolgreich gelscht.";
$locale["Your WikiDB DB backend '%s' cannot be used for DbSession."] =
   "Ihr WikiDB DB backend '%s' wird von DbSession nicht untersttzt.";
$locale["Your access permissions are only for a BogoUser."] =
   "Ihre Zugriffsberechtigung entspricht lediglich einem BogoUser.";
$locale["Your are probably trying to edit/create an invalid version of this page."] =
   "Sie versuchen offenbar eine ungltige Version dieser Seite zu bearbeiten.";
$locale["Your careful attention to detail is much appreciated."] =
   "Die besondere Aufmerksamkeit, die Sie soeben der Bearbeitung dieser Seite gewidmet haben, wird von allen Benutzern dieses Wikis gern gesehen und hoch geschtzt.";
$locale["Your changes can not be saved as they are, since doing so would overwrite the other author's changes. So, your changes and those of the other author have been combined. The result is shown below."] =
   "Ihre nderungen knnen so, wie sie sind, nicht gespeichert werden. Das htte unzulssigerweise die bereits gesicherten nderungen des anderen Autors berschrieben. Deshalb sind Ihre und die nderungen des anderen Autors miteinander kombiniert worden. Das Ergebnis sehen Sie unten.";
$locale["Your home page has not been created yet so your preferences cannot not be saved."] =
   "Sie haben Ihre persnliche HomePage Seite noch nicht erstellt, deshalb knnen Ihre Einstellungen nicht gespeichert werden.";
$locale["Your home page is locked so your preferences cannot not be saved."] =
   "Ihre persnliche HomePage Seite ist gesperrt, deshalb knnen Ihre nderungen nicht gespeichert werden.";
$locale["Your rating "] =
   "Deine Bewertung ";
$locale["Your rating was %.1f"] =
   "Deine Bewertung war %.1f";
$locale["Your signature"] =
   "Deine Signatur";
$locale["Your translated text doesn't yet appear in this %s, but the Administrator will pick it up and add to the installation."] =
   "Dein bersetzter Text erscheint noch nicht in %s, aber ein Administrator wird sich darum kmmern.";
$locale["Your translation is stored in %s"] =
   "Deine bersetzung ist in %s abgespeichert";
$locale["Your version"] =
   "Ihre Version";
$locale["ZIP files of database"] =
   "Speichern und Archivieren";
$locale["[%d] See [%s]"] =
   "[%d] Siehe [%s]";
$locale["[not purgable]"] =
   "[nicht entfernbar]";
$locale["[purged]"] =
   "[entfernt]";
$locale["_WikiTranslation"] =
   "_Wikibersetzung";
$locale["access this wiki via SOAP"] =
   "um via SOAP auf dieses Wiki zuzugreifen";
$locale["access this wiki via XML-RPC"] =
   "um via XML-RPC auf dieses Wiki zuzugreifen";
$locale["add "] =
   "hinzufgen ";
$locale["argument '%s' not declared by plugin"] =
   "Argument %s nicht im Zusatzprogramm deklariert";
$locale["authenticated"] =
   "authentifizierten";
$locale["blog"] =
   "Blog";
$locale["by"] =
   "mit";
$locale["by %s"] =
   "von %s";
$locale["cached pagedata:"] =
   "Seitendaten in den Cachespeicher aufgenommen:";
$locale["cached versiondata:"] =
   "Versionendaten in den Cachespeicher aufgenommen:";
$locale["case-exact"] =
   "Gro-/Kleinschreibung beachten";
$locale["change page '%s' to markup type '%s'."] =
   "Formattierung der Seite '%s' auf '%s' gendert.";
$locale["check for ACCESS_LOG_SQL passwords in POST requests"] =
   "prfe auf ACCESS_LOG_SQL Passwrter in POST Requests";
$locale["check for mysql 4.1.x/5.0.0 binary search on windows problem"] =
   "prfe auf mysql 4.1.x/5.0.0 Binrsuch-Problem (nur Windows)";
$locale["check for mysql LOCK TABLE privilege"] =
   "prfe mysql LOCK TABLE Rechte";
$locale["check for mysql page.id auto_increment flag"] =
   "prfe auf mysql page.id auto_increment Flag";
$locale["check for mysql session.sess_id sanity"] =
   "prfe auf mysql session.sess_id Korrektheit";
$locale["check for new session.sess_ip column"] =
   "prfe auf neue Spalte session.sess_ip column";
$locale["check for table %s"] =
   "prfe Tabelle %s";
$locale["chmod page '%s' to '%s'."] =
   "Berechtigung der Seite '%s' auf '%s' gendert.";
$locale["comments"] =
   "Kommentare";
$locale["compare revisions"] =
   "Versionen vergleichen";
$locale["content is identical to current version %d - no new revision created"] =
   "Inhalt ist identisch mit der aktuellen Version %d - keine neue Version erzeugt";
$locale["couldn't move %s to %s"] =
   "Kann %s nicht nach %s verschieben";
$locale["couldn't open file '%s' for writing"] =
   "Datei %s konnte nicht zum Schreiben geffnet werden";
$locale["create this page"] =
   "um diese Seite zu erzeugen";
$locale["current version"] =
   "aktuelle Version";
$locale["days"] =
   "Tage";
$locale["default page permission"] =
   "Vorgabe Zugriffsrecht";
$locale["diff"] =
   "diff";
$locale["diff this page"] =
   "um von dieser Seite die nderungen anzuzeigen";
$locale["download a zip dump from this wiki"] =
   "um eine gezippte Sicherung von allen Wiki Seiten herunterzuladen";
$locale["download an html zip dump from this wiki"] =
   "um alle HTML Seiten als Zipdatei von diesem Wiki herunterzuladen";
$locale["dump html pages"] =
   "um von diesem Wiki HTML-Dateien lokal abzuspeichern";
$locale["dump serial pages"] =
   "um von diesem Wiki die Seiten lokal abzuspeichern";
$locale["edit area"] =
   "Texteingabe Fenster";
$locale["edit this page"] =
   "um diese Seite zu bearbeiten";
$locale["edits"] =
   "nderungen";
$locale["empty source"] =
   "fehlender Quelltext";
$locale["fixed"] =
   "Gendert";
$locale["from"] =
   "von";
$locale["from %s"] =
   "von %s";
$locale["getfacl"] =
   "getfacl";
$locale["has edit conflicts - overwriting anyway"] =
   "hat unauflsbare Konflikte beim Speichern - wird ungeprft berschrieben";
$locale["has edit conflicts - skipped"] =
   "hat unauflsbare Konflikte beim Speichern - bersprungen";
$locale["home page"] =
   "Start Seite";
$locale["hours"] =
   "Stunden";
$locale["invalid %s ignored"] =
   "ungltiges %s ignoriert";
$locale["invalid argument %s"] =
   "Ungltiger Parameter %s";
$locale["invidual page permission"] =
   "individuelles Zugriffsrecht";
$locale["latest comment by "] =
   "Letzter Kommentar von ";
$locale["load files into this wiki"] =
   "um Seiten in dieses Wiki zu laden";
$locale["lock this page"] =
   "um diese Seite zu sperren";
$locale["locked"] =
   "gesperrt";
$locale["major edits"] =
   "Grssere nderungen";
$locale["max: %d"] =
   "Max: %d";
$locale["mean: %2.3f"] =
   "Mittel: %2.3f";
$locale["median: %d"] =
   "Median: %d";
$locale["minor"] =
   "kleinere";
$locale["minor edit"] =
   "geringfgige";
$locale["minor edits"] =
   "Kleinere nderungen";
$locale["minutes"] =
   "Minuten";
$locale["missing required version argument"] =
   "Parameter version mu angegeben werden";
$locale["mode"] =
   "mode";
$locale["n/a"] =
   "k.A.";
$locale["name"] =
   "Name";
$locale["newer than the existing page."] =
   "neuer als die bestehende Seite.";
$locale["no RSS items"] =
   "keine RSS Eintrge";
$locale["no cache used"] =
   "kein Cache verwendet";
$locale["no page content"] =
   "leerer Seiteninalt";
$locale["no page specified"] =
   "Keine Seite angegeben";
$locale["not affected"] =
   "nicht betroffen";
$locale["not authenticated"] =
   "nicht authentifizierten";
$locale["not yet"] =
   "noch nicht";
$locale["older than the existing page."] =
   "lter als die bestehende Seite.";
$locale["only %d pages displayed"] =
   "nur %d Seiten angezeigt";
$locale["optional label | PageName"] =
   "optionaler Name | SeitenName";
$locale["optional label | http://www.example.com"] =
   "optionaler Name | http://www.example.com";
$locale["page permission inherited from %s"] =
   "Zugriffsrecht geerbt von %s";
$locale["period"] =
   "Version %d.";
$locale["plain file %s"] =
   "Nur-Text-Datei %s";
$locale["predecessor to the previous major change"] =
   "Vorgnger zur vorherigen grsseren nderung";
$locale["previous revision"] =
   "vorige Neubearbeitung";
$locale["recursive inclusion of page %s"] =
   "Fehler beim Einbetten der Seite %s: Rekursiver Selbstaufruf der Seite";
$locale["recursive inclusion of page %s ignored"] =
   "Fehler beim Einfgen der Seite %s: rekursiver Selbstaufruf ignoriert";
$locale["recursive inclusion of url %s"] =
   "Fehler beim Aufruf der Seite %s: Rekursion (sich selbst aufrufend)";
$locale["regex"] =
   "Regulrer Ausdruck";
$locale["remove this page"] =
   "um diese Seite zu lschen";
$locale["renamed from %s"] =
   "umbenannt von %s";
$locale["revert to a previous version of this page"] =
   "Zurckspeichern einer lteren Version dieser Seite.";
$locale["revert to version %d"] =
   "Speichere Version %d zurck.";
$locale["revision by previous author"] =
   "Revidierte Ausgabe des vorigen Autors";
$locale["same version page"] =
   "selbe Version der Seite";
$locale["saved as "] =
   "gespeichert als ";
$locale["saved as %s"] =
   "gespeichert als %s";
$locale["stddev: %2.3f"] =
   "Standardabweichung: %2.3f";
$locale["the file '%s'"] =
   "die Datei %s";
$locale["the session.save_path directory '%s'"] =
   "das session.save_path Verzeichnis %s";
$locale["to"] =
   "nach";
$locale["today"] =
   "heute";
$locale["too long"] =
   "zu lang";
$locale["total hits: %d"] =
   "Anzahl aller Seitenaufrufe %d";
$locale["trailing cruft in plugin args: '%s'"] =
   "berflssiger Mll in den Zusatzprogramm Argumenten: %s";
$locale["unknown color %s ignored"] =
   "unbekannte Farbe %s ignoriert";
$locale["unlock this page"] =
   "um diese Seite zu entsperren";
$locale["upload a zip dump"] =
   "um einen ZIP-Speicherauszug in dieses Wiki zu laden";
$locale["uploaded %s"] =
   "%s wurde hochgeladen";
$locale["use this plugin"] =
   "um diese Zusatzprogramme zu verwenden";
$locale["users"] =
   "Benutzer";
$locale["verify the current action"] =
   "um die gegenwrtige Aktion durchzufhren";
$locale["version %d"] =
   "Version %d.";
$locale["version %s"] =
   "Version %s";
$locale["version <em>%s</em>"] =
   "version <em>%s</em>";
$locale["version <em>%s</em> not affected"] =
   "version <em>%s</em> nicht betroffen";
$locale["view the source of this page"] =
   "um den Quelltext dieser Seiten anzusehen";
$locale["view this page"] =
   "um diese Seite anzuzeigen";
$locale["weeks"] =
   "Wochen";
$locale["yesterday"] =
   "gestern";

?>
